@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
  *	Manjeet Dahiya
@@ -21,26 +21,31 @@
  *
  */
 
-
 #ifndef XMPPCLIENT_H
 #define XMPPCLIENT_H
 
 #include "QXmppClient.h"
 
+class QXmppRosterManager;
 class QXmppVCardIq;
+class QXmppVCardManager;
 
 class xmppClient : public QXmppClient
 {
     Q_OBJECT
 
 public:
-    xmppClient(QObject *parent = 0);
-    ~xmppClient();
+    xmppClient(QObject *parent = nullptr);
+    ~xmppClient() override;
 
 public slots:
     void clientConnected();
     void rosterReceived();
-    void vCardReceived(const QXmppVCardIq&);
+    void vCardReceived(const QXmppVCardIq &);
+
+private:
+    QXmppRosterManager *m_rosterManager;
+    QXmppVCardManager *m_vCardManager;
 };
 
-#endif // XMPPCLIENT_H
+#endif  // XMPPCLIENT_H
