@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -24,17 +24,17 @@
 #ifndef QXMPPJINGLEIQ_H
 #define QXMPPJINGLEIQ_H
 
-#include <QHostAddress>
-
 #include "QXmppIq.h"
 
+#include <QHostAddress>
+
 class QXmppJingleCandidatePrivate;
 class QXmppJingleIqContentPrivate;
 class QXmppJingleIqPrivate;
 class QXmppJinglePayloadTypePrivate;
 
 /// \brief The QXmppJinglePayloadType class represents a payload type
-/// as specified by XEP-0167: Jingle RTP Sessions and RFC 5245.
+/// as specified by \xep{0167}: Jingle RTP Sessions and RFC 5245.
 ///
 
 class QXMPP_EXPORT QXmppJinglePayloadType
@@ -70,7 +70,7 @@ public:
     void toXml(QXmlStreamWriter *writer) const;
     /// \endcond
 
-    QXmppJinglePayloadType& operator=(const QXmppJinglePayloadType &other);
+    QXmppJinglePayloadType &operator=(const QXmppJinglePayloadType &other);
     bool operator==(const QXmppJinglePayloadType &other) const;
 
 private:
@@ -78,29 +78,28 @@ private:
 };
 
 /// \brief The QXmppJingleCandidate class represents a transport candidate
-/// as specified by XEP-0176: Jingle ICE-UDP Transport Method.
+/// as specified by \xep{0176}: Jingle ICE-UDP Transport Method.
 ///
 
 class QXMPP_EXPORT QXmppJingleCandidate
 {
 public:
     /// This enum is used to describe a candidate's type.
-    enum Type
-    {
-        HostType,               ///< Host candidate, a local address/port.
-        PeerReflexiveType,      ///< Peer-reflexive candidate,
-                                ///< the address/port as seen from the peer.
-        ServerReflexiveType,    ///< Server-reflexive candidate,
-                                ///< the address/port as seen by the STUN server
-        RelayedType             ///< Relayed candidate, a candidate from
-                                ///< a TURN relay.
+    enum Type {
+        HostType,             ///< Host candidate, a local address/port.
+        PeerReflexiveType,    ///< Peer-reflexive candidate,
+                              ///< the address/port as seen from the peer.
+        ServerReflexiveType,  ///< Server-reflexive candidate,
+                              ///< the address/port as seen by the STUN server
+        RelayedType           ///< Relayed candidate, a candidate from
+                              ///< a TURN relay.
     };
 
     QXmppJingleCandidate();
     QXmppJingleCandidate(const QXmppJingleCandidate &other);
     ~QXmppJingleCandidate();
 
-    QXmppJingleCandidate& operator=(const QXmppJingleCandidate &other);
+    QXmppJingleCandidate &operator=(const QXmppJingleCandidate &other);
 
     int component() const;
     void setComponent(int component);
@@ -138,7 +137,7 @@ public:
     void parse(const QDomElement &element);
     void toXml(QXmlStreamWriter *writer) const;
 
-    static QXmppJingleCandidate::Type typeFromString(const QString &typeStr, bool *ok = 0);
+    static QXmppJingleCandidate::Type typeFromString(const QString &typeStr, bool *ok = nullptr);
     static QString typeToString(QXmppJingleCandidate::Type type);
     /// \endcond
 
@@ -147,7 +146,7 @@ private:
 };
 
 /// \brief The QXmppJingleIq class represents an IQ used for initiating media
-/// sessions as specified by XEP-0166: Jingle.
+/// sessions as specified by \xep{0166}: Jingle.
 ///
 /// \ingroup Stanzas
 
@@ -185,7 +184,7 @@ public:
         Content(const QXmppJingleIq::Content &other);
         ~Content();
 
-        Content& operator=(const Content &other);
+        Content &operator=(const Content &other);
 
         QString creator() const;
         void setCreator(const QString &creator);
@@ -289,9 +288,9 @@ public:
 
     QXmppJingleIq();
     QXmppJingleIq(const QXmppJingleIq &other);
-    ~QXmppJingleIq();
+    ~QXmppJingleIq() override;
 
-    QXmppJingleIq& operator=(const QXmppJingleIq &other);
+    QXmppJingleIq &operator=(const QXmppJingleIq &other);
 
     Action action() const;
     void setAction(Action action);
@@ -303,8 +302,8 @@ public:
     QString initiator() const;
     void setInitiator(const QString &initiator);
 
-    Reason& reason();
-    const Reason& reason() const;
+    Reason &reason();
+    const Reason &reason() const;
 
     QString responder() const;
     void setResponder(const QString &responder);
@@ -322,8 +321,8 @@ public:
 
 protected:
     /// \cond
-    void parseElementFromChild(const QDomElement &element);
-    void toXmlElementFromChild(QXmlStreamWriter *writer) const;
+    void parseElementFromChild(const QDomElement &element) override;
+    void toXmlElementFromChild(QXmlStreamWriter *writer) const override;
     /// \endcond
 
 private:
