@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -21,14 +21,15 @@
  *
  */
 
+#include "QXmppNonSASLAuth.h"
+
+#include "QXmppConstants_p.h"
+#include "QXmppUtils.h"
+
 #include <QCryptographicHash>
 #include <QDomElement>
 #include <QXmlStreamWriter>
 
-#include "QXmppConstants_p.h"
-#include "QXmppNonSASLAuth.h"
-#include "QXmppUtils.h"
-
 QXmppNonSASLAuthIq::QXmppNonSASLAuthIq()
     : QXmppIq(QXmppIq::Set)
 {
@@ -39,7 +40,7 @@ QString QXmppNonSASLAuthIq::username() const
     return m_username;
 }
 
-void QXmppNonSASLAuthIq::setUsername( const QString &username )
+void QXmppNonSASLAuthIq::setUsername(const QString &username)
 {
     m_username = username;
 }
@@ -59,7 +60,7 @@ QString QXmppNonSASLAuthIq::password() const
     return m_password;
 }
 
-void QXmppNonSASLAuthIq::setPassword( const QString &password )
+void QXmppNonSASLAuthIq::setPassword(const QString &password)
 {
     m_password = password;
 }
@@ -77,31 +78,31 @@ void QXmppNonSASLAuthIq::setResource(const QString &resource)
 /// \cond
 bool QXmppNonSASLAuthIq::isNonSASLAuthIq(const QDomElement &element)
 {
-    QDomElement queryElement = element.firstChildElement("query");
+    QDomElement queryElement = element.firstChildElement(QStringLiteral("query"));
     return queryElement.namespaceURI() == ns_auth;
 }
 
 void QXmppNonSASLAuthIq::parseElementFromChild(const QDomElement &element)
 {
-    QDomElement queryElement = element.firstChildElement("query");
-    m_username = queryElement.firstChildElement("username").text();
-    m_password = queryElement.firstChildElement("password").text();
-    m_digest = QByteArray::fromHex(queryElement.firstChildElement("digest").text().toLatin1());
-    m_resource = queryElement.firstChildElement("resource").text();
+    QDomElement queryElement = element.firstChildElement(QStringLiteral("query"));
+    m_username = queryElement.firstChildElement(QStringLiteral("username")).text();
+    m_password = queryElement.firstChildElement(QStringLiteral("password")).text();
+    m_digest = QByteArray::fromHex(queryElement.firstChildElement(QStringLiteral("digest")).text().toLatin1());
+    m_resource = queryElement.firstChildElement(QStringLiteral("resource")).text();
 }
 
 void QXmppNonSASLAuthIq::toXmlElementFromChild(QXmlStreamWriter *writer) const
 {
-    writer->writeStartElement("query");
-    writer->writeAttribute("xmlns", ns_auth);
+    writer->writeStartElement(QStringLiteral("query"));
+    writer->writeDefaultNamespace(ns_auth);
     if (!m_username.isEmpty())
-        writer->writeTextElement("username", m_username);
+        writer->writeTextElement(QStringLiteral("username"), m_username);
     if (!m_digest.isEmpty())
-        writer->writeTextElement("digest", m_digest.toHex());
+        writer->writeTextElement(QStringLiteral("digest"), m_digest.toHex());
     if (!m_password.isEmpty())
-        writer->writeTextElement("password", m_password);
+        writer->writeTextElement(QStringLiteral("password"), m_password);
     if (!m_resource.isEmpty())
-        writer->writeTextElement("resource", m_resource);
+        writer->writeTextElement(QStringLiteral("resource"), m_resource);
     writer->writeEndElement();
 }
 /// \endcond
