@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
- *  Olivier Goffart <ogoffart@woboq.com>
+ *  Olivier Goffart
  *
  * Source:
  *  https://github.com/qxmpp-project/qxmpp
@@ -21,18 +21,18 @@
  *
  */
 
+#include "QXmppResultSet.h"
 
 #include "QXmppConstants_p.h"
-#include "QXmppResultSet.h"
 #include "QXmppUtils.h"
 
-#include <QDomElement>
 #include <QDebug>
+#include <QDomElement>
 
 QXmppResultSetQuery::QXmppResultSetQuery()
-    : m_index(-1)
-    , m_max(-1)
-{}
+    : m_index(-1), m_max(-1)
+{
+}
 
 /// Returns the maximum number of results.
 ///
@@ -68,7 +68,7 @@ int QXmppResultSetQuery::index() const
 
 void QXmppResultSetQuery::setIndex(int index)
 {
-    m_index=index;
+    m_index = index;
 }
 
 /// Returns the UID of the first result in the next page.
@@ -86,7 +86,7 @@ QString QXmppResultSetQuery::before() const
 
 void QXmppResultSetQuery::setBefore(const QString& before)
 {
-    m_before=before;
+    m_before = before;
 }
 
 /// Returns the UID of the last result in the previous page.
@@ -104,7 +104,7 @@ QString QXmppResultSetQuery::after() const
 
 void QXmppResultSetQuery::setAfter(const QString& after)
 {
-    m_after=after;
+    m_after = after;
 }
 
 /// Returns true if no result set information is present.
@@ -117,15 +117,17 @@ bool QXmppResultSetQuery::isNull() const
 /// \cond
 void QXmppResultSetQuery::parse(const QDomElement& element)
 {
-    QDomElement setElement = (element.tagName() == "set") ? element : element.firstChildElement("set");
+    QDomElement setElement = (element.tagName() == QStringLiteral("set")) ? element : element.firstChildElement(QStringLiteral("set"));
     if (setElement.namespaceURI() == ns_rsm) {
         bool ok = false;
-        m_max = setElement.firstChildElement("max").text().toInt(&ok);
-        if (!ok) m_max = -1;
-        m_after = setElement.firstChildElement("after").text();
-        m_before = setElement.firstChildElement("before").text();
-        m_index = setElement.firstChildElement("index").text().toInt(&ok);
-        if (!ok) m_index = -1;
+        m_max = setElement.firstChildElement(QStringLiteral("max")).text().toInt(&ok);
+        if (!ok)
+            m_max = -1;
+        m_after = setElement.firstChildElement(QStringLiteral("after")).text();
+        m_before = setElement.firstChildElement(QStringLiteral("before")).text();
+        m_index = setElement.firstChildElement(QStringLiteral("index")).text().toInt(&ok);
+        if (!ok)
+            m_index = -1;
     }
 }
 
@@ -133,24 +135,24 @@ void QXmppResultSetQuery::toXml(QXmlStreamWriter* writer) const
 {
     if (isNull())
         return;
-    writer->writeStartElement("set");
-    writer->writeAttribute("xmlns", ns_rsm);
+    writer->writeStartElement(QStringLiteral("set"));
+    writer->writeDefaultNamespace(ns_rsm);
     if (m_max >= 0)
-        helperToXmlAddTextElement(writer, "max", QString::number(m_max));
+        helperToXmlAddTextElement(writer, QStringLiteral("max"), QString::number(m_max));
     if (!m_after.isNull())
-        helperToXmlAddTextElement(writer, "after", m_after);
+        helperToXmlAddTextElement(writer, QStringLiteral("after"), m_after);
     if (!m_before.isNull())
-        helperToXmlAddTextElement(writer, "before", m_before);
+        helperToXmlAddTextElement(writer, QStringLiteral("before"), m_before);
     if (m_index >= 0)
-        helperToXmlAddTextElement(writer, "index", QString::number(m_index));
+        helperToXmlAddTextElement(writer, QStringLiteral("index"), QString::number(m_index));
     writer->writeEndElement();
 }
 /// \endcond
 
 QXmppResultSetReply::QXmppResultSetReply()
-    : m_count(-1)
-    , m_index(-1)
-{}
+    : m_count(-1), m_index(-1)
+{
+}
 
 /// Returns the UID of the first result in the page.
 
@@ -163,7 +165,7 @@ QString QXmppResultSetReply::first() const
 
 void QXmppResultSetReply::setFirst(const QString& first)
 {
-    m_first=first;
+    m_first = first;
 }
 
 /// Returns the UID of the last result in the page.
@@ -177,7 +179,7 @@ QString QXmppResultSetReply::last() const
 
 void QXmppResultSetReply::setLast(const QString& last)
 {
-    m_last=last;
+    m_last = last;
 }
 
 /// Returns the total number of items in the set.
@@ -237,7 +239,8 @@ void QXmppResultSetReply::parse(const QDomElement& element)
         m_first = firstElem.text();
         bool ok = false;
         m_index = firstElem.attribute("index").toInt(&ok);
-        if(!ok) m_index = -1;
+        if (!ok)
+            m_index = -1;
         m_last = setElement.firstChildElement("last").text();
     }
 }
@@ -247,7 +250,7 @@ void QXmppResultSetReply::toXml(QXmlStreamWriter* writer) const
     if (isNull())
         return;
     writer->writeStartElement("set");
-    writer->writeAttribute("xmlns", ns_rsm);
+    writer->writeDefaultNamespace(ns_rsm);
     if (!m_first.isNull() || m_index >= 0) {
         writer->writeStartElement("first");
         if (m_index >= 0)
