@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Authors:
  *  Manjeet Dahiya
@@ -22,16 +22,18 @@
  *
  */
 
-#include <cstdlib>
-
-#include <QCryptographicHash>
-#include <QDomElement>
-#include <QStringList>
-#include <QUrlQuery>
-
 #include "QXmppSasl_p.h"
 #include "QXmppUtils.h"
 
+#include <cstdlib>
+
+#include <QByteArray>
+#include <QDomElement>
+#include <QMessageAuthenticationCode>
+#include <QStringList>
+#include <QUrlQuery>
+#include <QtEndian>
+
 const char *ns_xmpp_sasl = "urn:ietf:params:xml:ns:xmpp-sasl";
 
 static QByteArray forcedNonce;
@@ -49,6 +51,36 @@ static QByteArray calculateDigest(const QByteArray &method, const QByteArray &di
     return QCryptographicHash::hash(KD, QCryptographicHash::Md5).toHex();
 }
 
+// Perform PBKFD2 key derivation, code taken from Qt 5.12
+
+static QByteArray deriveKeyPbkdf2(QCryptographicHash::Algorithm algorithm,
+                                  const QByteArray &data, const QByteArray &salt,
+                                  int iterations, quint64 dkLen)
+{
+    QByteArray key;
+    quint32 currentIteration = 1;
+    QMessageAuthenticationCode hmac(algorithm, data);
+    QByteArray index(4, Qt::Uninitialized);
+    while (quint64(key.length()) < dkLen) {
+        hmac.addData(salt);
+        qToBigEndian(currentIteration, reinterpret_cast<uchar *>(index.data()));
+        hmac.addData(index);
+        QByteArray u = hmac.result();
+        hmac.reset();
+        QByteArray tkey = u;
+        for (int iter = 1; iter < iterations; iter++) {
+            hmac.addData(u);
+            u = hmac.result();
+            hmac.reset();
+            std::transform(tkey.cbegin(), tkey.cend(), u.cbegin(), tkey.begin(),
+                           std::bit_xor<char>());
+        }
+        key += tkey;
+        currentIteration++;
+    }
+    return key.left(dkLen);
+}
+
 static QByteArray generateNonce()
 {
     if (!forcedNonce.isEmpty())
@@ -61,9 +93,19 @@ static QByteArray generateNonce()
     return nonce.toBase64();
 }
 
+static QMap<char, QByteArray> parseGS2(const QByteArray &ba)
+{
+    QMap<char, QByteArray> map;
+    for (const auto &keyValue : ba.split(',')) {
+        if (keyValue.size() >= 2 && keyValue[1] == '=') {
+            map[keyValue[0]] = keyValue.mid(2);
+        }
+    }
+    return map;
+}
+
 QXmppSaslAuth::QXmppSaslAuth(const QString &mechanism, const QByteArray &value)
-    : m_mechanism(mechanism)
-    , m_value(value)
+    : m_mechanism(mechanism), m_value(value)
 {
 }
 
@@ -89,15 +131,15 @@ void QXmppSaslAuth::setValue(const QByteArray &value)
 
 void QXmppSaslAuth::parse(const QDomElement &element)
 {
-    m_mechanism = element.attribute("mechanism");
+    m_mechanism = element.attribute(QStringLiteral("mechanism"));
     m_value = QByteArray::fromBase64(element.text().toLatin1());
 }
 
 void QXmppSaslAuth::toXml(QXmlStreamWriter *writer) const
 {
-    writer->writeStartElement("auth");
-    writer->writeAttribute("xmlns", ns_xmpp_sasl);
-    writer->writeAttribute("mechanism", m_mechanism);
+    writer->writeStartElement(QStringLiteral("auth"));
+    writer->writeDefaultNamespace(ns_xmpp_sasl);
+    writer->writeAttribute(QStringLiteral("mechanism"), m_mechanism);
     if (!m_value.isEmpty())
         writer->writeCharacters(m_value.toBase64());
     writer->writeEndElement();
@@ -125,8 +167,8 @@ void QXmppSaslChallenge::parse(const QDomElement &element)
 
 void QXmppSaslChallenge::toXml(QXmlStreamWriter *writer) const
 {
-    writer->writeStartElement("challenge");
-    writer->writeAttribute("xmlns", ns_xmpp_sasl);
+    writer->writeStartElement(QStringLiteral("challenge"));
+    writer->writeDefaultNamespace(ns_xmpp_sasl);
     if (!m_value.isEmpty())
         writer->writeCharacters(m_value.toBase64());
     writer->writeEndElement();
@@ -154,8 +196,8 @@ void QXmppSaslFailure::parse(const QDomElement &element)
 
 void QXmppSaslFailure::toXml(QXmlStreamWriter *writer) const
 {
-    writer->writeStartElement("failure");
-    writer->writeAttribute("xmlns", ns_xmpp_sasl);
+    writer->writeStartElement(QStringLiteral("failure"));
+    writer->writeDefaultNamespace(ns_xmpp_sasl);
     if (!m_condition.isEmpty())
         writer->writeEmptyElement(m_condition);
     writer->writeEndElement();
@@ -183,8 +225,8 @@ void QXmppSaslResponse::parse(const QDomElement &element)
 
 void QXmppSaslResponse::toXml(QXmlStreamWriter *writer) const
 {
-    writer->writeStartElement("response");
-    writer->writeAttribute("xmlns", ns_xmpp_sasl);
+    writer->writeStartElement(QStringLiteral("response"));
+    writer->writeDefaultNamespace(ns_xmpp_sasl);
     if (!m_value.isEmpty())
         writer->writeCharacters(m_value.toBase64());
     writer->writeEndElement();
@@ -201,8 +243,8 @@ void QXmppSaslSuccess::parse(const QDomElement &element)
 
 void QXmppSaslSuccess::toXml(QXmlStreamWriter *writer) const
 {
-    writer->writeStartElement("success");
-    writer->writeAttribute("xmlns", ns_xmpp_sasl);
+    writer->writeStartElement(QStringLiteral("success"));
+    writer->writeDefaultNamespace(ns_xmpp_sasl);
     writer->writeEndElement();
 }
 
@@ -216,8 +258,7 @@ public:
 };
 
 QXmppSaslClient::QXmppSaslClient(QObject *parent)
-    : QXmppLoggable(parent)
-    , d(new QXmppSaslClientPrivate)
+    : QXmppLoggable(parent), d(new QXmppSaslClientPrivate)
 {
 }
 
@@ -230,27 +271,38 @@ QXmppSaslClient::~QXmppSaslClient()
 
 QStringList QXmppSaslClient::availableMechanisms()
 {
-    return QStringList() << "PLAIN" << "DIGEST-MD5" << "ANONYMOUS" << "X-FACEBOOK-PLATFORM" << "X-MESSENGER-OAUTH2" << "X-OAUTH2";
+    return QStringList() << QStringLiteral("SCRAM-SHA-256")
+                         << QStringLiteral("SCRAM-SHA-1")
+                         << QStringLiteral("DIGEST-MD5")
+                         << QStringLiteral("PLAIN")
+                         << QStringLiteral("ANONYMOUS")
+                         << QStringLiteral("X-FACEBOOK-PLATFORM")
+                         << QStringLiteral("X-MESSENGER-OAUTH2")
+                         << QStringLiteral("X-OAUTH2");
 }
 
 /// Creates an SASL client for the given mechanism.
 
-QXmppSaslClient* QXmppSaslClient::create(const QString &mechanism, QObject *parent)
+QXmppSaslClient *QXmppSaslClient::create(const QString &mechanism, QObject *parent)
 {
-    if (mechanism == "PLAIN") {
+    if (mechanism == QStringLiteral("PLAIN")) {
         return new QXmppSaslClientPlain(parent);
-    } else if (mechanism == "DIGEST-MD5") {
+    } else if (mechanism == QStringLiteral("DIGEST-MD5")) {
         return new QXmppSaslClientDigestMd5(parent);
-    } else if (mechanism == "ANONYMOUS") {
+    } else if (mechanism == QStringLiteral("ANONYMOUS")) {
         return new QXmppSaslClientAnonymous(parent);
-    } else if (mechanism == "X-FACEBOOK-PLATFORM") {
+    } else if (mechanism == QStringLiteral("SCRAM-SHA-1")) {
+        return new QXmppSaslClientScram(QCryptographicHash::Sha1, parent);
+    } else if (mechanism == QStringLiteral("SCRAM-SHA-256")) {
+        return new QXmppSaslClientScram(QCryptographicHash::Sha256, parent);
+    } else if (mechanism == QStringLiteral("X-FACEBOOK-PLATFORM")) {
         return new QXmppSaslClientFacebook(parent);
-    } else if (mechanism == "X-MESSENGER-OAUTH2") {
+    } else if (mechanism == QStringLiteral("X-MESSENGER-OAUTH2")) {
         return new QXmppSaslClientWindowsLive(parent);
-    } else if (mechanism == "X-OAUTH2") {
+    } else if (mechanism == QStringLiteral("X-OAUTH2")) {
         return new QXmppSaslClientGoogle(parent);
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -311,14 +363,13 @@ void QXmppSaslClient::setPassword(const QString &password)
 }
 
 QXmppSaslClientAnonymous::QXmppSaslClientAnonymous(QObject *parent)
-    : QXmppSaslClient(parent)
-    , m_step(0)
+    : QXmppSaslClient(parent), m_step(0)
 {
 }
 
 QString QXmppSaslClientAnonymous::mechanism() const
 {
-    return "ANONYMOUS";
+    return QStringLiteral("ANONYMOUS");
 }
 
 bool QXmppSaslClientAnonymous::respond(const QByteArray &challenge, QByteArray &response)
@@ -329,15 +380,13 @@ bool QXmppSaslClientAnonymous::respond(const QByteArray &challenge, QByteArray &
         m_step++;
         return true;
     } else {
-        warning("QXmppSaslClientAnonymous : Invalid step");
+        warning(QStringLiteral("QXmppSaslClientAnonymous : Invalid step"));
         return false;
     }
 }
 
 QXmppSaslClientDigestMd5::QXmppSaslClientDigestMd5(QObject *parent)
-    : QXmppSaslClient(parent)
-    , m_nc("00000001")
-    , m_step(0)
+    : QXmppSaslClient(parent), m_nc(QByteArrayLiteral("00000001")), m_step(0)
 {
     m_cnonce = generateNonce();
 }
@@ -350,7 +399,7 @@ QString QXmppSaslClientDigestMd5::mechanism() const
 bool QXmppSaslClientDigestMd5::respond(const QByteArray &challenge, QByteArray &response)
 {
     Q_UNUSED(challenge);
-    const QByteArray digestUri = QString("%1/%2").arg(serviceType(), host()).toUtf8();
+    const QByteArray digestUri = QStringLiteral("%1/%2").arg(serviceType(), host()).toUtf8();
 
     if (m_step == 0) {
         response = QByteArray();
@@ -359,38 +408,38 @@ bool QXmppSaslClientDigestMd5::respond(const QByteArray &challenge, QByteArray &
     } else if (m_step == 1) {
         const QMap<QByteArray, QByteArray> input = QXmppSaslDigestMd5::parseMessage(challenge);
 
-        if (!input.contains("nonce")) {
-            warning("QXmppSaslClientDigestMd5 : Invalid input on step 1");
+        if (!input.contains(QByteArrayLiteral("nonce"))) {
+            warning(QStringLiteral("QXmppSaslClientDigestMd5 : Invalid input on step 1"));
             return false;
         }
 
         // determine realm
-        const QByteArray realm = input.value("realm");
+        const QByteArray realm = input.value(QByteArrayLiteral("realm"));
 
         // determine quality of protection
-        const QList<QByteArray> qops = input.value("qop", "auth").split(',');
-        if (!qops.contains("auth")) {
-            warning("QXmppSaslClientDigestMd5 : Invalid quality of protection");
+        const QList<QByteArray> qops = input.value(QByteArrayLiteral("qop"), QByteArrayLiteral("auth")).split(',');
+        if (!qops.contains(QByteArrayLiteral("auth"))) {
+            warning(QStringLiteral("QXmppSaslClientDigestMd5 : Invalid quality of protection"));
             return false;
         }
 
-        m_nonce = input.value("nonce");
+        m_nonce = input.value(QByteArrayLiteral("nonce"));
         m_secret = QCryptographicHash::hash(
-            username().toUtf8() + ":" + realm + ":" + password().toUtf8(),
+            username().toUtf8() + QByteArrayLiteral(":") + realm + QByteArrayLiteral(":") + password().toUtf8(),
             QCryptographicHash::Md5);
 
         // Build response
         QMap<QByteArray, QByteArray> output;
-        output["username"] = username().toUtf8();
+        output[QByteArrayLiteral("username")] = username().toUtf8();
         if (!realm.isEmpty())
-            output["realm"] = realm;
-        output["nonce"] = m_nonce;
-        output["qop"] = "auth";
-        output["cnonce"] = m_cnonce;
-        output["nc"] = m_nc;
-        output["digest-uri"] = digestUri;
-        output["response"] = calculateDigest("AUTHENTICATE", digestUri, m_secret, m_nonce, m_cnonce, m_nc);
-        output["charset"] = "utf-8";
+            output[QByteArrayLiteral("realm")] = realm;
+        output[QByteArrayLiteral("nonce")] = m_nonce;
+        output[QByteArrayLiteral("qop")] = QByteArrayLiteral("auth");
+        output[QByteArrayLiteral("cnonce")] = m_cnonce;
+        output[QByteArrayLiteral("nc")] = m_nc;
+        output[QByteArrayLiteral("digest-uri")] = digestUri;
+        output[QByteArrayLiteral("response")] = calculateDigest(QByteArrayLiteral("AUTHENTICATE"), digestUri, m_secret, m_nonce, m_cnonce, m_nc);
+        output[QByteArrayLiteral("charset")] = QByteArrayLiteral("utf-8");
 
         response = QXmppSaslDigestMd5::serializeMessage(output);
         m_step++;
@@ -399,8 +448,8 @@ bool QXmppSaslClientDigestMd5::respond(const QByteArray &challenge, QByteArray &
         const QMap<QByteArray, QByteArray> input = QXmppSaslDigestMd5::parseMessage(challenge);
 
         // check new challenge
-        if (input.value("rspauth") != calculateDigest(QByteArray(), digestUri, m_secret, m_nonce, m_cnonce, m_nc)) {
-            warning("QXmppSaslClientDigestMd5 : Invalid challenge on step 2");
+        if (input.value(QByteArrayLiteral("rspauth")) != calculateDigest(QByteArray(), digestUri, m_secret, m_nonce, m_cnonce, m_nc)) {
+            warning(QStringLiteral("QXmppSaslClientDigestMd5 : Invalid challenge on step 2"));
             return false;
         }
 
@@ -408,20 +457,19 @@ bool QXmppSaslClientDigestMd5::respond(const QByteArray &challenge, QByteArray &
         m_step++;
         return true;
     } else {
-        warning("QXmppSaslClientDigestMd5 : Invalid step");
+        warning(QStringLiteral("QXmppSaslClientDigestMd5 : Invalid step"));
         return false;
     }
 }
 
 QXmppSaslClientFacebook::QXmppSaslClientFacebook(QObject *parent)
-    : QXmppSaslClient(parent)
-    , m_step(0)
+    : QXmppSaslClient(parent), m_step(0)
 {
 }
 
 QString QXmppSaslClientFacebook::mechanism() const
 {
-    return "X-FACEBOOK-PLATFORM";
+    return QStringLiteral("X-FACEBOOK-PLATFORM");
 }
 
 bool QXmppSaslClientFacebook::respond(const QByteArray &challenge, QByteArray &response)
@@ -434,39 +482,38 @@ bool QXmppSaslClientFacebook::respond(const QByteArray &challenge, QByteArray &r
     } else if (m_step == 1) {
         // parse request
         QUrlQuery requestUrl(challenge);
-        if (!requestUrl.hasQueryItem("method") || !requestUrl.hasQueryItem("nonce")) {
-            warning("QXmppSaslClientFacebook : Invalid challenge, nonce or method missing");
+        if (!requestUrl.hasQueryItem(QStringLiteral("method")) || !requestUrl.hasQueryItem(QStringLiteral("nonce"))) {
+            warning(QStringLiteral("QXmppSaslClientFacebook : Invalid challenge, nonce or method missing"));
             return false;
         }
 
         // build response
         QUrlQuery responseUrl;
-        responseUrl.addQueryItem("access_token", password());
-        responseUrl.addQueryItem("api_key", username());
-        responseUrl.addQueryItem("call_id", 0);
-        responseUrl.addQueryItem("method", requestUrl.queryItemValue("method"));
-        responseUrl.addQueryItem("nonce", requestUrl.queryItemValue("nonce"));
-        responseUrl.addQueryItem("v", "1.0");
+        responseUrl.addQueryItem(QStringLiteral("access_token"), password());
+        responseUrl.addQueryItem(QStringLiteral("api_key"), username());
+        responseUrl.addQueryItem(QStringLiteral("call_id"), nullptr);
+        responseUrl.addQueryItem(QStringLiteral("method"), requestUrl.queryItemValue(QStringLiteral("method")));
+        responseUrl.addQueryItem(QStringLiteral("nonce"), requestUrl.queryItemValue(QStringLiteral("nonce")));
+        responseUrl.addQueryItem(QStringLiteral("v"), QStringLiteral("1.0"));
 
         response = responseUrl.query().toUtf8();
 
         m_step++;
         return true;
     } else {
-        warning("QXmppSaslClientFacebook : Invalid step");
+        warning(QStringLiteral("QXmppSaslClientFacebook : Invalid step"));
         return false;
     }
 }
 
 QXmppSaslClientGoogle::QXmppSaslClientGoogle(QObject *parent)
-    : QXmppSaslClient(parent)
-    , m_step(0)
+    : QXmppSaslClient(parent), m_step(0)
 {
 }
 
 QString QXmppSaslClientGoogle::mechanism() const
 {
-    return "X-OAUTH2";
+    return QStringLiteral("X-OAUTH2");
 }
 
 bool QXmppSaslClientGoogle::respond(const QByteArray &challenge, QByteArray &response)
@@ -478,20 +525,19 @@ bool QXmppSaslClientGoogle::respond(const QByteArray &challenge, QByteArray &res
         m_step++;
         return true;
     } else {
-        warning("QXmppSaslClientGoogle : Invalid step");
+        warning(QStringLiteral("QXmppSaslClientGoogle : Invalid step"));
         return false;
     }
 }
 
 QXmppSaslClientPlain::QXmppSaslClientPlain(QObject *parent)
-    : QXmppSaslClient(parent)
-    , m_step(0)
+    : QXmppSaslClient(parent), m_step(0)
 {
 }
 
 QString QXmppSaslClientPlain::mechanism() const
 {
-    return "PLAIN";
+    return QStringLiteral("PLAIN");
 }
 
 bool QXmppSaslClientPlain::respond(const QByteArray &challenge, QByteArray &response)
@@ -502,20 +548,87 @@ bool QXmppSaslClientPlain::respond(const QByteArray &challenge, QByteArray &resp
         m_step++;
         return true;
     } else {
-        warning("QXmppSaslClientPlain : Invalid step");
+        warning(QStringLiteral("QXmppSaslClientPlain : Invalid step"));
+        return false;
+    }
+}
+
+QXmppSaslClientScram::QXmppSaslClientScram(QCryptographicHash::Algorithm algorithm, QObject *parent)
+    : QXmppSaslClient(parent), m_algorithm(algorithm), m_step(0)
+{
+    Q_ASSERT(m_algorithm == QCryptographicHash::Sha1 || m_algorithm == QCryptographicHash::Sha256);
+    m_nonce = generateNonce();
+
+    if (m_algorithm == QCryptographicHash::Sha256) {
+        m_dklen = 32;
+        m_mechanism = QStringLiteral("SCRAM-SHA-256");
+    } else {
+        m_dklen = 20;
+        m_mechanism = QStringLiteral("SCRAM-SHA-1");
+    }
+}
+
+QString QXmppSaslClientScram::mechanism() const
+{
+    return m_mechanism;
+}
+
+bool QXmppSaslClientScram::respond(const QByteArray &challenge, QByteArray &response)
+{
+    Q_UNUSED(challenge);
+    if (m_step == 0) {
+        m_gs2Header = QByteArrayLiteral("n,,");
+        m_clientFirstMessageBare = QByteArrayLiteral("n=") + username().toUtf8() + QByteArrayLiteral(",r=") + m_nonce;
+
+        response = m_gs2Header + m_clientFirstMessageBare;
+        m_step++;
+        return true;
+    } else if (m_step == 1) {
+        // validate input
+        const QMap<char, QByteArray> input = parseGS2(challenge);
+        const QByteArray nonce = input.value('r');
+        const QByteArray salt = QByteArray::fromBase64(input.value('s'));
+        const int iterations = input.value('i').toInt();
+        if (!nonce.startsWith(m_nonce) || salt.isEmpty() || iterations < 1) {
+            return false;
+        }
+
+        // calculate proofs
+        const QByteArray clientFinalMessageBare = QByteArrayLiteral("c=") + m_gs2Header.toBase64() + QByteArrayLiteral(",r=") + nonce;
+        const QByteArray saltedPassword = deriveKeyPbkdf2(m_algorithm, password().toUtf8(), salt,
+                                                          iterations, m_dklen);
+        const QByteArray clientKey = QMessageAuthenticationCode::hash(QByteArrayLiteral("Client Key"), saltedPassword, m_algorithm);
+        const QByteArray storedKey = QCryptographicHash::hash(clientKey, m_algorithm);
+        const QByteArray authMessage = m_clientFirstMessageBare + QByteArrayLiteral(",") + challenge + QByteArrayLiteral(",") + clientFinalMessageBare;
+        QByteArray clientProof = QMessageAuthenticationCode::hash(authMessage, storedKey, m_algorithm);
+        std::transform(clientProof.cbegin(), clientProof.cend(), clientKey.cbegin(),
+                       clientProof.begin(), std::bit_xor<char>());
+
+        const QByteArray serverKey = QMessageAuthenticationCode::hash(QByteArrayLiteral("Server Key"), saltedPassword, m_algorithm);
+        m_serverSignature = QMessageAuthenticationCode::hash(authMessage, serverKey, m_algorithm);
+
+        response = clientFinalMessageBare + QByteArrayLiteral(",p=") + clientProof.toBase64();
+        m_step++;
+        return true;
+    } else if (m_step == 2) {
+        const QMap<char, QByteArray> input = parseGS2(challenge);
+        response = QByteArray();
+        m_step++;
+        return QByteArray::fromBase64(input.value('v')) == m_serverSignature;
+    } else {
+        warning(QStringLiteral("QXmppSaslClientPlain : Invalid step"));
         return false;
     }
 }
 
 QXmppSaslClientWindowsLive::QXmppSaslClientWindowsLive(QObject *parent)
-    : QXmppSaslClient(parent)
-    , m_step(0)
+    : QXmppSaslClient(parent), m_step(0)
 {
 }
 
 QString QXmppSaslClientWindowsLive::mechanism() const
 {
-    return "X-MESSENGER-OAUTH2";
+    return QStringLiteral("X-MESSENGER-OAUTH2");
 }
 
 bool QXmppSaslClientWindowsLive::respond(const QByteArray &challenge, QByteArray &response)
@@ -527,7 +640,7 @@ bool QXmppSaslClientWindowsLive::respond(const QByteArray &challenge, QByteArray
         m_step++;
         return true;
     } else {
-        warning("QXmppSaslClientWindowsLive : Invalid step");
+        warning(QStringLiteral("QXmppSaslClientWindowsLive : Invalid step"));
         return false;
     }
 }
@@ -542,8 +655,7 @@ public:
 };
 
 QXmppSaslServer::QXmppSaslServer(QObject *parent)
-    : QXmppLoggable(parent)
-    , d(new QXmppSaslServerPrivate)
+    : QXmppLoggable(parent), d(new QXmppSaslServerPrivate)
 {
 }
 
@@ -554,16 +666,16 @@ QXmppSaslServer::~QXmppSaslServer()
 
 /// Creates an SASL server for the given mechanism.
 
-QXmppSaslServer* QXmppSaslServer::create(const QString &mechanism, QObject *parent)
+QXmppSaslServer *QXmppSaslServer::create(const QString &mechanism, QObject *parent)
 {
-    if (mechanism == "PLAIN") {
+    if (mechanism == QStringLiteral("PLAIN")) {
         return new QXmppSaslServerPlain(parent);
-    } else if (mechanism == "DIGEST-MD5") {
+    } else if (mechanism == QStringLiteral("DIGEST-MD5")) {
         return new QXmppSaslServerDigestMd5(parent);
-    } else if (mechanism == "ANONYMOUS") {
+    } else if (mechanism == QStringLiteral("ANONYMOUS")) {
         return new QXmppSaslServerAnonymous(parent);
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -624,14 +736,13 @@ void QXmppSaslServer::setRealm(const QString &realm)
 }
 
 QXmppSaslServerAnonymous::QXmppSaslServerAnonymous(QObject *parent)
-    : QXmppSaslServer(parent)
-    , m_step(0)
+    : QXmppSaslServer(parent), m_step(0)
 {
 }
 
 QString QXmppSaslServerAnonymous::mechanism() const
 {
-    return "ANONYMOUS";
+    return QStringLiteral("ANONYMOUS");
 }
 
 QXmppSaslServer::Response QXmppSaslServerAnonymous::respond(const QByteArray &request, QByteArray &response)
@@ -642,66 +753,65 @@ QXmppSaslServer::Response QXmppSaslServerAnonymous::respond(const QByteArray &re
         response = QByteArray();
         return Succeeded;
     } else {
-        warning("QXmppSaslServerAnonymous : Invalid step");
+        warning(QStringLiteral("QXmppSaslServerAnonymous : Invalid step"));
         return Failed;
     }
 }
 
 QXmppSaslServerDigestMd5::QXmppSaslServerDigestMd5(QObject *parent)
-    : QXmppSaslServer(parent)
-    , m_step(0)
+    : QXmppSaslServer(parent), m_step(0)
 {
     m_nonce = generateNonce();
 }
 
 QString QXmppSaslServerDigestMd5::mechanism() const
 {
-    return "DIGEST-MD5";
+    return QStringLiteral("DIGEST-MD5");
 }
 
 QXmppSaslServer::Response QXmppSaslServerDigestMd5::respond(const QByteArray &request, QByteArray &response)
 {
     if (m_step == 0) {
         QMap<QByteArray, QByteArray> output;
-        output["nonce"] = m_nonce;
+        output[QByteArrayLiteral("nonce")] = m_nonce;
         if (!realm().isEmpty())
-            output["realm"] = realm().toUtf8();
-        output["qop"] = "auth";
-        output["charset"] = "utf-8";
-        output["algorithm"] = "md5-sess";
+            output[QByteArrayLiteral("realm")] = realm().toUtf8();
+        output[QByteArrayLiteral("qop")] = QByteArrayLiteral("auth");
+        output[QByteArrayLiteral("charset")] = QByteArrayLiteral("utf-8");
+        output[QByteArrayLiteral("algorithm")] = QByteArrayLiteral("md5-sess");
 
         m_step++;
         response = QXmppSaslDigestMd5::serializeMessage(output);
         return Challenge;
     } else if (m_step == 1) {
         const QMap<QByteArray, QByteArray> input = QXmppSaslDigestMd5::parseMessage(request);
-        const QByteArray realm = input.value("realm");
-        const QByteArray digestUri = input.value("digest-uri");
+        const QByteArray realm = input.value(QByteArrayLiteral("realm"));
+        const QByteArray digestUri = input.value(QByteArrayLiteral("digest-uri"));
 
-        if (input.value("qop") != "auth") {
-            warning("QXmppSaslServerDigestMd5 : Invalid quality of protection");
+        if (input.value(QByteArrayLiteral("qop")) != QByteArrayLiteral("auth")) {
+            warning(QStringLiteral("QXmppSaslServerDigestMd5 : Invalid quality of protection"));
             return Failed;
         }
 
-        setUsername(QString::fromUtf8(input.value("username")));
+        setUsername(QString::fromUtf8(input.value(QByteArrayLiteral("username"))));
         if (password().isEmpty() && passwordDigest().isEmpty())
             return InputNeeded;
 
-        m_nc = input.value("nc");
-        m_cnonce = input.value("cnonce");
+        m_nc = input.value(QByteArrayLiteral("nc"));
+        m_cnonce = input.value(QByteArrayLiteral("cnonce"));
         if (!password().isEmpty()) {
             m_secret = QCryptographicHash::hash(
-                username().toUtf8() + ":" + realm + ":" + password().toUtf8(),
+                username().toUtf8() + QByteArrayLiteral(":") + realm + QByteArrayLiteral(":") + password().toUtf8(),
                 QCryptographicHash::Md5);
         } else {
             m_secret = passwordDigest();
         }
 
-        if (input.value("response") != calculateDigest("AUTHENTICATE", digestUri, m_secret, m_nonce, m_cnonce, m_nc))
+        if (input.value(QByteArrayLiteral("response")) != calculateDigest(QByteArrayLiteral("AUTHENTICATE"), digestUri, m_secret, m_nonce, m_cnonce, m_nc))
             return Failed;
 
         QMap<QByteArray, QByteArray> output;
-        output["rspauth"] = calculateDigest(QByteArray(), digestUri, m_secret, m_nonce, m_cnonce, m_nc);
+        output[QByteArrayLiteral("rspauth")] = calculateDigest(QByteArray(), digestUri, m_secret, m_nonce, m_cnonce, m_nc);
 
         m_step++;
         response = QXmppSaslDigestMd5::serializeMessage(output);
@@ -711,20 +821,19 @@ QXmppSaslServer::Response QXmppSaslServerDigestMd5::respond(const QByteArray &re
         response = QByteArray();
         return Succeeded;
     } else {
-        warning("QXmppSaslServerDigestMd5 : Invalid step");
+        warning(QStringLiteral("QXmppSaslServerDigestMd5 : Invalid step"));
         return Failed;
     }
 }
 
 QXmppSaslServerPlain::QXmppSaslServerPlain(QObject *parent)
-    : QXmppSaslServer(parent)
-    , m_step(0)
+    : QXmppSaslServer(parent), m_step(0)
 {
 }
 
 QString QXmppSaslServerPlain::mechanism() const
 {
-    return "PLAIN";
+    return QStringLiteral("PLAIN");
 }
 
 QXmppSaslServer::Response QXmppSaslServerPlain::respond(const QByteArray &request, QByteArray &response)
@@ -737,7 +846,7 @@ QXmppSaslServer::Response QXmppSaslServerPlain::respond(const QByteArray &reques
 
         QList<QByteArray> auth = request.split('\0');
         if (auth.size() != 3) {
-            warning("QXmppSaslServerPlain : Invalid input");
+            warning(QStringLiteral("QXmppSaslServerPlain : Invalid input"));
             return Failed;
         }
         setUsername(QString::fromUtf8(auth[1]));
@@ -747,7 +856,7 @@ QXmppSaslServer::Response QXmppSaslServerPlain::respond(const QByteArray &reques
         response = QByteArray();
         return InputNeeded;
     } else {
-        warning("QXmppSaslServerPlain : Invalid step");
+        warning(QStringLiteral("QXmppSaslServerPlain : Invalid step"));
         return Failed;
     }
 }
@@ -762,23 +871,20 @@ QMap<QByteArray, QByteArray> QXmppSaslDigestMd5::parseMessage(const QByteArray &
     QMap<QByteArray, QByteArray> map;
     int startIndex = 0;
     int pos = 0;
-    while ((pos = ba.indexOf("=", startIndex)) >= 0)
-    {
+    while ((pos = ba.indexOf(QStringLiteral("="), startIndex)) >= 0) {
         // key get name and skip equals
         const QByteArray key = ba.mid(startIndex, pos - startIndex).trimmed();
         pos++;
 
         // check whether string is quoted
-        if (ba.at(pos) == '"')
-        {
+        if (ba.at(pos) == '"') {
             // skip opening quote
             pos++;
             int endPos = ba.indexOf('"', pos);
             // skip quoted quotes
             while (endPos >= 0 && ba.at(endPos - 1) == '\\')
                 endPos = ba.indexOf('"', endPos + 1);
-            if (endPos < 0)
-            {
+            if (endPos < 0) {
                 qWarning("Unfinished quoted string");
                 return map;
             }
@@ -805,29 +911,24 @@ QMap<QByteArray, QByteArray> QXmppSaslDigestMd5::parseMessage(const QByteArray &
 QByteArray QXmppSaslDigestMd5::serializeMessage(const QMap<QByteArray, QByteArray> &map)
 {
     QByteArray ba;
-    foreach (const QByteArray &key, map.keys())
-    {
+    for (const auto &key : map.keys()) {
         if (!ba.isEmpty())
             ba.append(',');
-        ba.append(key + "=");
+        ba.append(key + QByteArrayLiteral("="));
         QByteArray value = map[key];
         const char *separators = "()<>@,;:\\\"/[]?={} \t";
         bool quote = false;
-        for (const char *c = separators; *c; c++)
-        {
-            if (value.contains(*c))
-            {
+        for (const char *c = separators; *c; c++) {
+            if (value.contains(*c)) {
                 quote = true;
                 break;
             }
         }
-        if (quote)
-        {
-            value.replace("\\", "\\\\");
-            value.replace("\"", "\\\"");
-            ba.append("\"" + value + "\"");
-        }
-        else
+        if (quote) {
+            value.replace(QByteArrayLiteral("\\"), QByteArrayLiteral("\\\\"));
+            value.replace(QByteArrayLiteral("\""), QByteArrayLiteral("\\\""));
+            ba.append(QStringLiteral("\"") + value + QStringLiteral("\""));
+        } else
             ba.append(value);
     }
     return ba;
