@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -21,14 +21,14 @@
  *
  */
 
-
 #ifndef QXMPPVCARDIQ_H
 #define QXMPPVCARDIQ_H
 
 #include "QXmppIq.h"
+
 #include <QDate>
-#include <QMap>
 #include <QDomElement>
+#include <QMap>
 
 class QXmppVCardAddressPrivate;
 class QXmppVCardEmailPrivate;
@@ -43,11 +43,11 @@ class QXMPP_EXPORT QXmppVCardAddress
 public:
     /// \brief Describes e-mail address types.
     enum TypeFlag {
-        None        = 0x0,
-        Home        = 0x1,
-        Work        = 0x2,
-        Postal      = 0x4,
-        Preferred   = 0x8
+        None = 0x0,
+        Home = 0x1,
+        Work = 0x2,
+        Postal = 0x4,
+        Preferred = 0x8
     };
     Q_DECLARE_FLAGS(Type, TypeFlag)
 
@@ -55,7 +55,7 @@ public:
     QXmppVCardAddress(const QXmppVCardAddress &other);
     ~QXmppVCardAddress();
 
-    QXmppVCardAddress& operator=(const QXmppVCardAddress &other);
+    QXmppVCardAddress &operator=(const QXmppVCardAddress &other);
 
     QString country() const;
     void setCountry(const QString &country);
@@ -84,8 +84,8 @@ private:
     QSharedDataPointer<QXmppVCardAddressPrivate> d;
 };
 
-QXMPP_EXPORT bool operator==(const QXmppVCardAddress&, const QXmppVCardAddress&);
-QXMPP_EXPORT bool operator!=(const QXmppVCardAddress&, const QXmppVCardAddress&);
+QXMPP_EXPORT bool operator==(const QXmppVCardAddress &, const QXmppVCardAddress &);
+QXMPP_EXPORT bool operator!=(const QXmppVCardAddress &, const QXmppVCardAddress &);
 
 /// \brief Represents a vCard e-mail address.
 
@@ -94,12 +94,12 @@ class QXMPP_EXPORT QXmppVCardEmail
 public:
     /// \brief Describes e-mail address types.
     enum TypeFlag {
-        None        = 0x0,
-        Home        = 0x1,
-        Work        = 0x2,
-        Internet    = 0x4,
-        Preferred   = 0x8,
-        X400        = 0x10
+        None = 0x0,
+        Home = 0x1,
+        Work = 0x2,
+        Internet = 0x4,
+        Preferred = 0x8,
+        X400 = 0x10
     };
     Q_DECLARE_FLAGS(Type, TypeFlag)
 
@@ -107,7 +107,7 @@ public:
     QXmppVCardEmail(const QXmppVCardEmail &other);
     ~QXmppVCardEmail();
 
-    QXmppVCardEmail& operator=(const QXmppVCardEmail &other);
+    QXmppVCardEmail &operator=(const QXmppVCardEmail &other);
 
     QString address() const;
     void setAddress(const QString &address);
@@ -124,8 +124,8 @@ private:
     QSharedDataPointer<QXmppVCardEmailPrivate> d;
 };
 
-QXMPP_EXPORT bool operator==(const QXmppVCardEmail&, const QXmppVCardEmail&);
-QXMPP_EXPORT bool operator!=(const QXmppVCardEmail&, const QXmppVCardEmail&);
+QXMPP_EXPORT bool operator==(const QXmppVCardEmail &, const QXmppVCardEmail &);
+QXMPP_EXPORT bool operator!=(const QXmppVCardEmail &, const QXmppVCardEmail &);
 
 /// \brief Represents a vCard phone number.
 
@@ -134,20 +134,20 @@ class QXMPP_EXPORT QXmppVCardPhone
 public:
     /// \brief Describes phone number types.
     enum TypeFlag {
-        None        = 0x0,
-        Home        = 0x1,
-        Work        = 0x2,
-        Voice       = 0x4,
-        Fax         = 0x8,
-        Pager       = 0x10,
-        Messaging   = 0x20,
-        Cell        = 0x40,
-        Video       = 0x80,
-        BBS         = 0x100,
-        Modem       = 0x200,
-        ISDN        = 0x400,
-        PCS         = 0x800,
-        Preferred   = 0x1000
+        None = 0x0,
+        Home = 0x1,
+        Work = 0x2,
+        Voice = 0x4,
+        Fax = 0x8,
+        Pager = 0x10,
+        Messaging = 0x20,
+        Cell = 0x40,
+        Video = 0x80,
+        BBS = 0x100,
+        Modem = 0x200,
+        ISDN = 0x400,
+        PCS = 0x800,
+        Preferred = 0x1000
     };
     Q_DECLARE_FLAGS(Type, TypeFlag)
 
@@ -155,7 +155,7 @@ public:
     QXmppVCardPhone(const QXmppVCardPhone &other);
     ~QXmppVCardPhone();
 
-    QXmppVCardPhone& operator=(const QXmppVCardPhone &other);
+    QXmppVCardPhone &operator=(const QXmppVCardPhone &other);
 
     QString number() const;
     void setNumber(const QString &number);
@@ -172,8 +172,8 @@ private:
     QSharedDataPointer<QXmppVCardPhonePrivate> d;
 };
 
-QXMPP_EXPORT bool operator==(const QXmppVCardPhone&, const QXmppVCardPhone&);
-QXMPP_EXPORT bool operator!=(const QXmppVCardPhone&, const QXmppVCardPhone&);
+QXMPP_EXPORT bool operator==(const QXmppVCardPhone &, const QXmppVCardPhone &);
+QXMPP_EXPORT bool operator!=(const QXmppVCardPhone &, const QXmppVCardPhone &);
 
 /// \brief Represents organization information in XMPP vCards.
 ///
@@ -187,19 +187,19 @@ public:
     QXmppVCardOrganization(const QXmppVCardOrganization &other);
     ~QXmppVCardOrganization();
 
-    QXmppVCardOrganization& operator=(const QXmppVCardOrganization &other);
+    QXmppVCardOrganization &operator=(const QXmppVCardOrganization &other);
 
     QString organization() const;
-    void setOrganization(const QString&);
+    void setOrganization(const QString &);
 
     QString unit() const;
-    void setUnit(const QString&);
+    void setUnit(const QString &);
 
     QString title() const;
-    void setTitle(const QString&);
+    void setTitle(const QString &);
 
     QString role() const;
-    void setRole(const QString&);
+    void setRole(const QString &);
 
     /// \cond
     void parse(const QDomElement &element);
@@ -210,13 +210,13 @@ private:
     QSharedDataPointer<QXmppVCardOrganizationPrivate> d;
 };
 
-QXMPP_EXPORT bool operator==(const QXmppVCardOrganization&, const QXmppVCardOrganization&);
-QXMPP_EXPORT bool operator!=(const QXmppVCardOrganization&, const QXmppVCardOrganization&);
+QXMPP_EXPORT bool operator==(const QXmppVCardOrganization &, const QXmppVCardOrganization &);
+QXMPP_EXPORT bool operator!=(const QXmppVCardOrganization &, const QXmppVCardOrganization &);
 
 /// \brief Represents the XMPP vCard.
 ///
 /// The functions names are self explanatory.
-/// Look at QXmppVCardManager and XEP-0054: vcard-temp for more details.
+/// Look at QXmppVCardManager and \xep{0054}: vcard-temp for more details.
 ///
 /// There are many field of XMPP vCard which are not present in
 /// this class. File a issue for the same. We will add the requested
@@ -226,11 +226,11 @@ QXMPP_EXPORT bool operator!=(const QXmppVCardOrganization&, const QXmppVCardOrga
 class QXMPP_EXPORT QXmppVCardIq : public QXmppIq
 {
 public:
-    QXmppVCardIq(const QString& bareJid = QString());
+    QXmppVCardIq(const QString &bareJid = QString());
     QXmppVCardIq(const QXmppVCardIq &other);
-    ~QXmppVCardIq();
+    ~QXmppVCardIq() override;
 
-    QXmppVCardIq& operator=(const QXmppVCardIq &other);
+    QXmppVCardIq &operator=(const QXmppVCardIq &other);
 
     QDate birthday() const;
     void setBirthday(const QDate &birthday);
@@ -239,31 +239,31 @@ public:
     void setDescription(const QString &description);
 
     QString email() const;
-    void setEmail(const QString&);
+    void setEmail(const QString &);
 
     QString firstName() const;
-    void setFirstName(const QString&);
+    void setFirstName(const QString &);
 
     QString fullName() const;
-    void setFullName(const QString&);
+    void setFullName(const QString &);
 
     QString lastName() const;
-    void setLastName(const QString&);
+    void setLastName(const QString &);
 
     QString middleName() const;
-    void setMiddleName(const QString&);
+    void setMiddleName(const QString &);
 
     QString nickName() const;
-    void setNickName(const QString&);
+    void setNickName(const QString &);
 
     QByteArray photo() const;
-    void setPhoto(const QByteArray&);
+    void setPhoto(const QByteArray &);
 
     QString photoType() const;
     void setPhotoType(const QString &type);
 
     QString url() const;
-    void setUrl(const QString&);
+    void setUrl(const QString &);
 
     QList<QXmppVCardAddress> addresses() const;
     void setAddresses(const QList<QXmppVCardAddress> &addresses);
@@ -275,7 +275,7 @@ public:
     void setPhones(const QList<QXmppVCardPhone> &phones);
 
     QXmppVCardOrganization organization() const;
-    void setOrganization(const QXmppVCardOrganization&);
+    void setOrganization(const QXmppVCardOrganization &);
 
     /// \cond
     static bool isVCard(const QDomElement &element);
@@ -283,15 +283,15 @@ public:
 
 protected:
     /// \cond
-    void parseElementFromChild(const QDomElement&);
-    void toXmlElementFromChild(QXmlStreamWriter *writer) const;
+    void parseElementFromChild(const QDomElement &) override;
+    void toXmlElementFromChild(QXmlStreamWriter *writer) const override;
     /// \endcond
 
 private:
     QSharedDataPointer<QXmppVCardIqPrivate> d;
 };
 
-QXMPP_EXPORT bool operator==(const QXmppVCardIq&, const QXmppVCardIq&);
-QXMPP_EXPORT bool operator!=(const QXmppVCardIq&, const QXmppVCardIq&);
+QXMPP_EXPORT bool operator==(const QXmppVCardIq &, const QXmppVCardIq &);
+QXMPP_EXPORT bool operator!=(const QXmppVCardIq &, const QXmppVCardIq &);
 
-#endif // QXMPPVCARDIQ_H
+#endif  // QXMPPVCARDIQ_H
