@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -21,13 +21,14 @@
  *
  */
 
-#include <QDomElement>
+#include "QXmppArchiveManager.h"
 
 #include "QXmppArchiveIq.h"
-#include "QXmppArchiveManager.h"
 #include "QXmppClient.h"
 #include "QXmppConstants_p.h"
 
+#include <QDomElement>
+
 /// \cond
 QStringList QXmppArchiveManager::discoveryFeatures() const
 {
@@ -41,22 +42,17 @@ bool QXmppArchiveManager::handleStanza(const QDomElement &element)
         return false;
 
     // XEP-0136: Message Archiving
-    if(QXmppArchiveChatIq::isArchiveChatIq(element))
-    {
+    if (QXmppArchiveChatIq::isArchiveChatIq(element)) {
         QXmppArchiveChatIq archiveIq;
         archiveIq.parse(element);
         emit archiveChatReceived(archiveIq.chat(), archiveIq.resultSetReply());
         return true;
-    }
-    else if(QXmppArchiveListIq::isArchiveListIq(element))
-    {
+    } else if (QXmppArchiveListIq::isArchiveListIq(element)) {
         QXmppArchiveListIq archiveIq;
         archiveIq.parse(element);
         emit archiveListReceived(archiveIq.chats(), archiveIq.resultSetReply());
         return true;
-    }
-    else if(QXmppArchivePrefIq::isArchivePrefIq(element))
-    {
+    } else if (QXmppArchivePrefIq::isArchivePrefIq(element)) {
         // TODO: handle preference iq
         QXmppArchivePrefIq archiveIq;
         archiveIq.parse(element);
@@ -75,8 +71,8 @@ bool QXmppArchiveManager::handleStanza(const QDomElement &element)
 /// \param end Optional end time.
 /// \param rsm Optional Result Set Management query
 ///
-void QXmppArchiveManager::listCollections(const QString& jid, const QDateTime& start,
-                                          const QDateTime& end, const QXmppResultSetQuery &rsm)
+void QXmppArchiveManager::listCollections(const QString &jid, const QDateTime &start,
+                                          const QDateTime &end, const QXmppResultSetQuery &rsm)
 {
     QXmppArchiveListIq packet;
     packet.setResultSetQuery(rsm);
@@ -102,7 +98,6 @@ void QXmppArchiveManager::listCollections(const QString &jid, const QDateTime &s
     listCollections(jid, start, end, rsm);
 }
 
-
 /// Removes the specified collection(s).
 ///
 /// \param jid The JID of the collection
