@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -24,13 +24,13 @@
 #ifndef QXMPPCLIENT_H
 #define QXMPPCLIENT_H
 
-#include <QObject>
-#include <QAbstractSocket>
-
 #include "QXmppConfiguration.h"
 #include "QXmppLogger.h"
 #include "QXmppPresence.h"
 
+#include <QAbstractSocket>
+#include <QObject>
+
 class QSslError;
 
 class QXmppClientExtension;
@@ -39,6 +39,7 @@ class QXmppPresence;
 class QXmppMessage;
 class QXmppIq;
 class QXmppStream;
+class QXmppInternalClientExtension;
 
 // managers
 class QXmppDiscoveryIq;
@@ -46,10 +47,23 @@ class QXmppRosterManager;
 class QXmppVCardManager;
 class QXmppVersionManager;
 
-/// \defgroup Core
+///
+/// \defgroup Core Core classes
+///
+/// Core classes include all necessary classes to build a basic client or
+/// server application. This for example also includes the logging class
+/// QXmppLogger.
+///
 
-/// \defgroup Managers
+///
+/// \defgroup Managers Managers
+///
+/// Managers are used to extend the basic QXmppClient. Some of them are loaded
+/// by default, others need to be added to the client using
+/// QXmppClient::addExtension().
+///
 
+///
 /// \brief The QXmppClient class is the main class for using QXmpp.
 ///
 /// It provides the user all the required functionality to connect to the
@@ -64,9 +78,9 @@ class QXmppVersionManager;
 /// QXmppConfiguration::setAutoReconnectionEnabled().
 ///
 /// Not all the managers or extensions have been enabled by default. One can
-/// enable/disable the managers using the functions addExtension() and
-/// removeExtension(). findExtension() can be used to find reference/pointer to
-/// particular instansiated and enabled manager.
+/// enable/disable the managers using the functions \c addExtension() and
+/// \c removeExtension(). \c findExtension() can be used to find reference/
+/// pointer to particular instansiated and enabled manager.
 ///
 /// List of managers enabled by default:
 /// - QXmppRosterManager
@@ -80,37 +94,39 @@ class QXmppVersionManager;
 class QXMPP_EXPORT QXmppClient : public QXmppLoggable
 {
     Q_OBJECT
-    Q_ENUMS(Error State)
-    Q_PROPERTY(QXmppLogger* logger READ logger WRITE setLogger NOTIFY loggerChanged)
+
+    /// The QXmppLogger associated with the current QXmppClient
+    Q_PROPERTY(QXmppLogger *logger READ logger WRITE setLogger NOTIFY loggerChanged)
+    /// The client's current state
     Q_PROPERTY(State state READ state NOTIFY stateChanged)
 
 public:
     /// An enumeration for type of error.
     /// Error could come due a TCP socket or XML stream or due to various stanzas.
-    enum Error
-    {
-        NoError,            ///< No error.
-        SocketError,        ///< Error due to TCP socket.
-        KeepAliveError,     ///< Error due to no response to a keep alive.
-        XmppStreamError     ///< Error due to XML stream.
+    enum Error {
+        NoError,          ///< No error.
+        SocketError,      ///< Error due to TCP socket.
+        KeepAliveError,   ///< Error due to no response to a keep alive.
+        XmppStreamError,  ///< Error due to XML stream.
     };
+    Q_ENUM(Error)
 
     /// This enumeration describes a client state.
-    enum State
-    {
+    enum State {
         DisconnectedState,  ///< Disconnected from the server.
         ConnectingState,    ///< Trying to connect to the server.
         ConnectedState      ///< Connected to the server.
     };
+    Q_ENUM(State)
 
-    QXmppClient(QObject *parent = 0);
-    ~QXmppClient();
+    QXmppClient(QObject *parent = nullptr);
+    ~QXmppClient() override;
 
-    bool addExtension(QXmppClientExtension* extension);
-    bool insertExtension(int index, QXmppClientExtension* extension);
-    bool removeExtension(QXmppClientExtension* extension);
+    bool addExtension(QXmppClientExtension *extension);
+    bool insertExtension(int index, QXmppClientExtension *extension);
+    bool removeExtension(QXmppClientExtension *extension);
 
-    QList<QXmppClientExtension*> extensions();
+    QList<QXmppClientExtension *> extensions();
 
     /// \brief Returns the extension which can be cast into type T*, or 0
     /// if there is no such extension.
@@ -125,16 +141,40 @@ public:
     /// \endcode
     ///
     template<typename T>
-    T* findExtension()
+    T *findExtension()
     {
-        QList<QXmppClientExtension*> list = extensions();
-        for (int i = 0; i < list.size(); ++i)
-        {
-            T* extension = qobject_cast<T*>(list.at(i));
-            if(extension)
+        const QList<QXmppClientExtension *> list = extensions();
+        for (auto ext : list) {
+            T *extension = qobject_cast<T *>(ext);
+            if (extension)
                 return extension;
         }
-        return 0;
+        return nullptr;
+    }
+
+    /// \brief Returns the index of an extension
+    ///
+    /// Usage example:
+    /// \code
+    /// int index = client->indexOfExtension<QXmppDiscoveryManager>();
+    /// if (index > 0) {
+    ///     // extension found, do stuff...
+    /// } else {
+    ///     // extension not found
+    /// }
+    /// \endcode
+    ///
+    /// \since QXmpp 1.2
+    ///
+    template<typename T>
+    int indexOfExtension()
+    {
+        auto list = extensions();
+        for (int i = 0; i < list.size(); ++i) {
+            if (qobject_cast<T *>(list.at(i)) != nullptr)
+                return i;
+        }
+        return -1;
     }
 
     bool isAuthenticated() const;
@@ -147,22 +187,35 @@ public:
     void setClientPresence(const QXmppPresence &presence);
 
     QXmppConfiguration &configuration();
+
+    // documentation needs to be here, see https://stackoverflow.com/questions/49192523/
+    /// Returns the QXmppLogger associated with the current QXmppClient.
     QXmppLogger *logger() const;
     void setLogger(QXmppLogger *logger);
 
     QAbstractSocket::SocketError socketError();
     QString socketErrorString() const;
+
+    // documentation needs to be here, see https://stackoverflow.com/questions/49192523/
+    /// Returns the client's current state.
     State state() const;
     QXmppStanza::Error::Condition xmppStreamError();
 
-    QXmppRosterManager& rosterManager();
-    QXmppVCardManager& vCardManager();
-    QXmppVersionManager& versionManager();
+#if QXMPP_DEPRECATED_SINCE(1, 1)
+    QT_DEPRECATED_X("Use QXmppClient::findExtension<QXmppRosterManager>() instead")
+    QXmppRosterManager &rosterManager();
 
-signals:
+    QT_DEPRECATED_X("Use QXmppClient::findExtension<QXmppVCardManager>() instead")
+    QXmppVCardManager &vCardManager();
 
-    /// This signal is emitted when the client connects successfully to the XMPP
-    /// server i.e. when a successful XMPP connection is established.
+    QT_DEPRECATED_X("Use QXmppClient::findExtension<QXmppVersionManager>() instead")
+    QXmppVersionManager &versionManager();
+#endif
+
+Q_SIGNALS:
+
+    /// This signal is emitted when the client connects successfully to the
+    /// XMPP server i.e. when a successful XMPP connection is established.
     /// XMPP Connection involves following sequential steps:
     ///     - TCP socket connection
     ///     - Client sends start stream
@@ -175,15 +228,15 @@ signals:
     /// After all these steps a successful XMPP connection is established and
     /// connected() signal is emitted.
     ///
-    /// After the connected() signal is emitted QXmpp will send the roster request
-    /// to the server. On receiving the roster, QXmpp will emit
-    /// QXmppRosterManager::rosterReceived(). After this signal, QXmppRosterManager object gets
-    /// populated and you can use rosterManager() to get the handle of QXmppRosterManager object.
-    ///
+    /// After the connected() signal is emitted QXmpp will send the roster
+    /// request to the server. On receiving the roster, QXmpp will emit
+    /// QXmppRosterManager::rosterReceived(). After this signal,
+    /// QXmppRosterManager object gets populated and you can use
+    /// \c findExtension<QXmppRosterManager>() to get the handle of
+    /// QXmppRosterManager object.
     void connected();
 
     /// This signal is emitted when the XMPP connection disconnects.
-    ///
     void disconnected();
 
     /// This signal is emitted when the XMPP connection encounters any error.
@@ -221,17 +274,17 @@ signals:
     /// This signal is emitted when the client state changes.
     void stateChanged(QXmppClient::State state);
 
-public slots:
-    void connectToServer(const QXmppConfiguration&,
-                         const QXmppPresence& initialPresence =
-                         QXmppPresence());
+public Q_SLOTS:
+    void connectToServer(const QXmppConfiguration &,
+                         const QXmppPresence &initialPresence =
+                             QXmppPresence());
     void connectToServer(const QString &jid,
                          const QString &password);
     void disconnectFromServer();
-    bool sendPacket(const QXmppStanza&);
-    void sendMessage(const QString& bareJid, const QString& message);
+    bool sendPacket(const QXmppStanza &);
+    void sendMessage(const QString &bareJid, const QString &message);
 
-private slots:
+private Q_SLOTS:
     void _q_elementReceived(const QDomElement &element, bool &handled);
     void _q_reconnect();
     void _q_socketStateChanged(QAbstractSocket::SocketState state);
@@ -240,7 +293,9 @@ private slots:
     void _q_streamError(QXmppClient::Error error);
 
 private:
-    QXmppClientPrivate * const d;
+    QXmppClientPrivate *const d;
+
+    friend class QXmppInternalClientExtension;
 };
 
-#endif // QXMPPCLIENT_H
+#endif  // QXMPPCLIENT_H
