@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -50,7 +50,7 @@ class QXMPP_EXPORT QXmppClientExtension : public QXmppLoggable
 
 public:
     QXmppClientExtension();
-    virtual ~QXmppClientExtension();
+    ~QXmppClientExtension() override;
 
     virtual QStringList discoveryFeatures() const;
     virtual QList<QXmppDiscoveryIq::Identity> discoveryIdentities() const;
@@ -68,7 +68,7 @@ protected:
     virtual void setClient(QXmppClient *client);
 
 private:
-    QXmppClientExtensionPrivate * const d;
+    QXmppClientExtensionPrivate *const d;
 
     friend class QXmppClient;
 };
