@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -23,15 +23,16 @@
 
 #include "QXmppDiscoveryManager.h"
 
-#include <QDomElement>
-#include <QCoreApplication>
-
 #include "QXmppClient.h"
+#include "QXmppClient_p.h"
 #include "QXmppConstants_p.h"
 #include "QXmppDataForm.h"
 #include "QXmppDiscoveryIq.h"
-#include "QXmppStream.h"
 #include "QXmppGlobal.h"
+#include "QXmppStream.h"
+
+#include <QCoreApplication>
+#include <QDomElement>
 
 class QXmppDiscoveryManagerPrivate
 {
@@ -75,9 +76,9 @@ QString QXmppDiscoveryManager::requestInfo(const QString& jid, const QString& no
     request.setType(QXmppIq::Get);
     request.setQueryType(QXmppDiscoveryIq::InfoQuery);
     request.setTo(jid);
-    if(!node.isEmpty())
+    if (!node.isEmpty())
         request.setQueryNode(node);
-    if(client()->sendPacket(request))
+    if (client()->sendPacket(request))
         return request.id();
     else
         return QString();
@@ -94,16 +95,17 @@ QString QXmppDiscoveryManager::requestItems(const QString& jid, const QString& n
     request.setType(QXmppIq::Get);
     request.setQueryType(QXmppDiscoveryIq::ItemsQuery);
     request.setTo(jid);
-    if(!node.isEmpty())
+    if (!node.isEmpty())
         request.setQueryNode(node);
-    if(client()->sendPacket(request))
+    if (client()->sendPacket(request))
         return request.id();
     else
         return QString();
 }
 
+///
 /// Returns the client's full capabilities.
-
+///
 QXmppDiscoveryIq QXmppDiscoveryManager::capabilities()
 {
     QXmppDiscoveryIq iq;
@@ -112,19 +114,13 @@ QXmppDiscoveryIq QXmppDiscoveryManager::capabilities()
 
     // features
     QStringList features;
-    features
-        << ns_data              // XEP-0004: Data Forms
-        << ns_rsm               // XEP-0059: Result Set Management
-        << ns_xhtml_im          // XEP-0071: XHTML-IM
-        << ns_chat_states       // XEP-0085: Chat State Notifications
-        << ns_capabilities      // XEP-0115: Entity Capabilities
-        << ns_ping              // XEP-0199: XMPP Ping
-        << ns_attention         // XEP-0224: Attention
-        << ns_chat_markers;     // XEP-0333: Chat Markers
+    // add base features of the client
+    features << QXmppClientPrivate::discoveryFeatures();
 
-    foreach(QXmppClientExtension* extension, client()->extensions())
-    {
-        if(extension)
+    // add features of all registered extensions
+    const QList<QXmppClientExtension *> extensions = client()->extensions();
+    for (auto* extension : extensions) {
+        if (extension)
             features << extension->discoveryFeatures();
     }
 
@@ -139,9 +135,8 @@ QXmppDiscoveryIq QXmppDiscoveryManager::capabilities()
     identity.setName(clientName());
     identities << identity;
 
-    foreach(QXmppClientExtension* extension, client()->extensions())
-    {
-        if(extension)
+    for (auto* extension : client()->extensions()) {
+        if (extension)
             identities << extension->discoveryIdentities();
     }
 
@@ -158,7 +153,7 @@ QXmppDiscoveryIq QXmppDiscoveryManager::capabilities()
 ///
 /// \param node
 
-void QXmppDiscoveryManager::setClientCapabilitiesNode(const QString &node)
+void QXmppDiscoveryManager::setClientCapabilitiesNode(const QString& node)
 {
     d->clientCapabilitiesNode = node;
 }
@@ -234,7 +229,7 @@ QString QXmppDiscoveryManager::clientName() const
 }
 
 /// Returns the client's extended information form, as defined
-/// by XEP-0128 Service Discovery Extensions.
+/// by \xep{0128}: Service Discovery Extensions.
 
 QXmppDataForm QXmppDiscoveryManager::clientInfoForm() const
 {
@@ -242,9 +237,9 @@ QXmppDataForm QXmppDiscoveryManager::clientInfoForm() const
 }
 
 /// Sets the client's extended information form, as defined
-/// by XEP-0128 Service Discovery Extensions.
+/// by \xep{0128}: Service Discovery Extensions.
 
-void QXmppDiscoveryManager::setClientInfoForm(const QXmppDataForm &form)
+void QXmppDiscoveryManager::setClientInfoForm(const QXmppDataForm& form)
 {
     d->clientInfoForm = form;
 }
@@ -255,10 +250,9 @@ QStringList QXmppDiscoveryManager::discoveryFeatures() const
     return QStringList() << ns_disco_info;
 }
 
-bool QXmppDiscoveryManager::handleStanza(const QDomElement &element)
+bool QXmppDiscoveryManager::handleStanza(const QDomElement& element)
 {
-    if (element.tagName() == "iq" && QXmppDiscoveryIq::isDiscoveryIq(element))
-    {
+    if (element.tagName() == "iq" && QXmppDiscoveryIq::isDiscoveryIq(element)) {
         QXmppDiscoveryIq receivedIq;
         receivedIq.parse(element);
 
