@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Authors:
  *  Ian Reinhart Geiser
@@ -24,13 +24,13 @@
 #ifndef QXMPPINVOKABLE_H
 #define QXMPPINVOKABLE_H
 
-#include <QObject>
+#include "QXmppGlobal.h"
+
 #include <QHash>
+#include <QObject>
+#include <QStringList>
 #include <QVariant>
 #include <QWriteLocker>
-#include <QStringList>
-
-#include "QXmppGlobal.h"
 
 /**
 This is the base class for all objects that will be invokable via RPC.  All public slots of objects derived from this class will be exposed to the RPC interface.  As a note for all methods, they can only understand types that QVariant knows about.
@@ -39,41 +39,40 @@ This is the base class for all objects that will be invokable via RPC.  All publ
 */
 class QXMPP_EXPORT QXmppInvokable : public QObject
 {
-        Q_OBJECT
+    Q_OBJECT
 public:
-        QXmppInvokable( QObject *parent = 0 );
+    QXmppInvokable(QObject *parent = nullptr);
 
-        ~QXmppInvokable();
+    ~QXmppInvokable() override;
 
-        /**
+    /**
          * Execute a method on an object. with a set of arguments. This method is reentrant, and the method
          * that is invoked will be done in a thread safe manner.  It should be noted that while this method
          * is threadsafe and reentrant the side affects of the methods invoked may not be.
          */
-        QVariant dispatch( const QByteArray &method, const QList<QVariant> &args = QList<QVariant>() );
+    QVariant dispatch(const QByteArray &method, const QList<QVariant> &args = QList<QVariant>());
 
-        /**
+    /**
          * Utility method to convert a QList<QVariant> to a list of types for type
          * checking.
          */
-        static QList<QByteArray> paramTypes( const QList<QVariant> &params );
+    static QList<QByteArray> paramTypes(const QList<QVariant> &params);
 
-        /**
+    /**
           * Reimplement this method to return a true if the invoking JID is allowed to execute the method.
           */
-        virtual bool isAuthorized( const QString &jid ) const = 0;
+    virtual bool isAuthorized(const QString &jid) const = 0;
 
-public slots:
-        /**
+public Q_SLOTS:
+    /**
           * This provides a list of interfaces for introspection of the presented interface.
           */
-        QStringList interfaces() const;
+    QStringList interfaces() const;
 
 private:
-        void buildMethodHash();
-        QHash<QByteArray,int> m_methodHash;
-        QReadWriteLock m_lock;
+    void buildMethodHash();
+    QHash<QByteArray, int> m_methodHash;
+    QReadWriteLock m_lock;
 };
 
-
 #endif
