@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
  *  Georg Rudoy
@@ -24,11 +24,12 @@
 
 #include "QXmppMessageReceiptManager.h"
 
-#include <QDomElement>
-
+#include "QXmppClient.h"
 #include "QXmppConstants_p.h"
 #include "QXmppMessage.h"
-#include "QXmppClient.h"
+#include "QXmppUtils.h"
+
+#include <QDomElement>
 
 /// Constructs a QXmppMessageReceiptManager to handle incoming and outgoing
 /// message delivery receipts.
@@ -52,16 +53,21 @@ bool QXmppMessageReceiptManager::handleStanza(const QDomElement &stanza)
     QXmppMessage message;
     message.parse(stanza);
 
+    if (message.type() == QXmppMessage::Error)
+        return false;
+
     // Handle receipts and cancel any further processing.
     if (!message.receiptId().isEmpty()) {
-        emit messageDelivered(message.from(), message.receiptId());
+        // Buggy clients also mark carbon messages as received; to avoid this
+        // we check whether sender and receiver have the same bare JID.
+        if (QXmppUtils::jidToBareJid(message.from()) != QXmppUtils::jidToBareJid(message.to())) {
+            emit messageDelivered(message.from(), message.receiptId());
+        }
         return true;
     }
 
     // If requested, send a receipt.
-    if (message.isReceiptRequested()
-        && !message.from().isEmpty()
-        && !message.id().isEmpty()) {
+    if (message.isReceiptRequested() && !message.from().isEmpty() && !message.id().isEmpty()) {
         QXmppMessage receipt;
         receipt.setTo(message.from());
         receipt.setReceiptId(message.id());
