@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -36,7 +36,7 @@ class QXmppMucRoom;
 class QXmppMucRoomPrivate;
 
 /// \brief The QXmppMucManager class makes it possible to interact with
-/// multi-user chat rooms as defined by XEP-0045: Multi-User Chat.
+/// multi-user chat rooms as defined by \xep{0045}: Multi-User Chat.
 ///
 /// To make use of this manager, you need to instantiate it and load it into
 /// the QXmppClient instance as follows:
@@ -59,21 +59,24 @@ class QXmppMucRoomPrivate;
 class QXMPP_EXPORT QXmppMucManager : public QXmppClientExtension
 {
     Q_OBJECT
-    Q_PROPERTY(QList<QXmppMucRoom*> rooms READ rooms NOTIFY roomAdded)
+    Q_PROPERTY(QList<QXmppMucRoom *> rooms READ rooms NOTIFY roomAdded)
 
 public:
     QXmppMucManager();
-    ~QXmppMucManager();
+    ~QXmppMucManager() override;
 
     QXmppMucRoom *addRoom(const QString &roomJid);
-    QList<QXmppMucRoom*> rooms() const;
+
+    // documentation needs to be here, see https://stackoverflow.com/questions/49192523/
+    /// Returns the list of managed rooms.
+    QList<QXmppMucRoom *> rooms() const;
 
     /// \cond
-    QStringList discoveryFeatures() const;
-    bool handleStanza(const QDomElement &element);
+    QStringList discoveryFeatures() const override;
+    bool handleStanza(const QDomElement &element) override;
     /// \endcond
 
-signals:
+Q_SIGNALS:
     /// This signal is emitted when an invitation to a chat room is received.
     void invitationReceived(const QString &roomJid, const QString &inviter, const QString &reason);
 
@@ -82,10 +85,10 @@ signals:
 
 protected:
     /// \cond
-    void setClient(QXmppClient* client);
+    void setClient(QXmppClient *client) override;
     /// \endcond
 
-private slots:
+private Q_SLOTS:
     void _q_messageReceived(const QXmppMessage &message);
     void _q_roomDestroyed(QObject *object);
 
@@ -94,7 +97,7 @@ private:
 };
 
 /// \brief The QXmppMucRoom class represents a multi-user chat room
-/// as defined by XEP-0045: Multi-User Chat.
+/// as defined by \xep{0045}: Multi-User Chat.
 ///
 /// \sa QXmppMucManager
 
@@ -102,48 +105,84 @@ class QXMPP_EXPORT QXmppMucRoom : public QObject
 {
     Q_OBJECT
     Q_FLAGS(Action Actions)
+
+    /// The actions you are allowed to perform on the room
     Q_PROPERTY(QXmppMucRoom::Actions allowedActions READ allowedActions NOTIFY allowedActionsChanged)
+    /// Whether you are currently in the room
     Q_PROPERTY(bool isJoined READ isJoined NOTIFY isJoinedChanged)
+    /// The chat room's bare JID
     Q_PROPERTY(QString jid READ jid CONSTANT)
+    /// The chat room's human-readable name
     Q_PROPERTY(QString name READ name NOTIFY nameChanged)
+    /// Your own nickname
     Q_PROPERTY(QString nickName READ nickName WRITE setNickName NOTIFY nickNameChanged)
+    /// The list of participant JIDs
     Q_PROPERTY(QStringList participants READ participants NOTIFY participantsChanged)
+    /// The chat room password
     Q_PROPERTY(QString password READ password WRITE setPassword)
+    /// The room's subject
     Q_PROPERTY(QString subject READ subject WRITE setSubject NOTIFY subjectChanged)
 
 public:
-
     /// This enum is used to describe chat room actions.
     enum Action {
-        NoAction = 0,               ///< no action
-        SubjectAction = 1,          ///< change the room's subject
-        ConfigurationAction = 2,    ///< change the room's configuration
-        PermissionsAction = 4,      ///< change the room's permissions
-        KickAction = 8              ///< kick users from the room
+        NoAction = 0,             ///< no action
+        SubjectAction = 1,        ///< change the room's subject
+        ConfigurationAction = 2,  ///< change the room's configuration
+        PermissionsAction = 4,    ///< change the room's permissions
+        KickAction = 8            ///< kick users from the room
     };
     Q_DECLARE_FLAGS(Actions, Action)
 
-    ~QXmppMucRoom();
+    ~QXmppMucRoom() override;
 
+    // documentation needs to be here, see https://stackoverflow.com/questions/49192523/
+    /// Returns the actions you are allowed to perform on the room.
     Actions allowedActions() const;
+
+    // documentation needs to be here, see https://stackoverflow.com/questions/49192523/
+    /// Returns true if you are currently in the room.
     bool isJoined() const;
+
+    // documentation needs to be here, see https://stackoverflow.com/questions/49192523/
+    /// Returns the chat room's bare JID.
     QString jid() const;
+
+    // documentation needs to be here, see https://stackoverflow.com/questions/49192523/
+    ///
+    /// Returns the chat room's human-readable name.
+    ///
+    /// This name will only be available after the room has been joined.
+    ///
     QString name() const;
 
+    // documentation needs to be here, see https://stackoverflow.com/questions/49192523/
+    /// Returns your own nickname.
     QString nickName() const;
     void setNickName(const QString &nickName);
 
     Q_INVOKABLE QString participantFullJid(const QString &jid) const;
     QXmppPresence participantPresence(const QString &jid) const;
+
+    // documentation needs to be here, see https://stackoverflow.com/questions/49192523/
+    ///
+    /// Returns the list of participant JIDs.
+    ///
+    /// These JIDs are Occupant JIDs of the form "room@service/nick".
+    ///
     QStringList participants() const;
 
+    // documentation needs to be here, see https://stackoverflow.com/questions/49192523/
+    /// Returns the chat room password.
     QString password() const;
     void setPassword(const QString &password);
 
+    // documentation needs to be here, see https://stackoverflow.com/questions/49192523/
+    /// Returns the room's subject.
     QString subject() const;
     void setSubject(const QString &subject);
 
-signals:
+Q_SIGNALS:
     /// This signal is emitted when the allowed actions change.
     void allowedActionsChanged(QXmppMucRoom::Actions actions) const;
 
@@ -194,7 +233,7 @@ signals:
     /// This signal is emitted when the room's subject changes.
     void subjectChanged(const QString &subject);
 
-public slots:
+public Q_SLOTS:
     bool ban(const QString &jid, const QString &reason);
     bool join();
     bool kick(const QString &jid, const QString &reason);
@@ -206,7 +245,7 @@ public slots:
     bool sendInvitation(const QString &jid, const QString &reason);
     bool sendMessage(const QString &text);
 
-private slots:
+private Q_SLOTS:
     void _q_disconnected();
     void _q_discoveryInfoReceived(const QXmppDiscoveryIq &iq);
     void _q_messageReceived(const QXmppMessage &message);
