@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Authors:
  *  Manjeet Dahiya
@@ -22,7 +22,6 @@
  *
  */
 
-
 #ifndef QXMPPOUTGOINGCLIENT_H
 #define QXMPPOUTGOINGCLIENT_H
 
@@ -50,19 +49,19 @@ class QXMPP_EXPORT QXmppOutgoingClient : public QXmppStream
 
 public:
     QXmppOutgoingClient(QObject *parent);
-    ~QXmppOutgoingClient();
+    ~QXmppOutgoingClient() override;
 
     void connectToHost();
     bool isAuthenticated() const;
-    bool isConnected() const;
+    bool isConnected() const override;
     bool isClientStateIndicationEnabled() const;
 
     QSslSocket *socket() const { return QXmppStream::socket(); };
     QXmppStanza::Error::Condition xmppStreamError();
 
-    QXmppConfiguration& configuration();
+    QXmppConfiguration &configuration();
 
-signals:
+Q_SIGNALS:
     /// This signal is emitted when an error is encountered.
     void error(QXmppClient::Error);
 
@@ -70,13 +69,13 @@ signals:
     void elementReceived(const QDomElement &element, bool &handled);
 
     /// This signal is emitted when a presence is received.
-    void presenceReceived(const QXmppPresence&);
+    void presenceReceived(const QXmppPresence &);
 
     /// This signal is emitted when a message is received.
-    void messageReceived(const QXmppMessage&);
+    void messageReceived(const QXmppMessage &);
 
     /// This signal is emitted when an IQ is received.
-    void iqReceived(const QXmppIq&);
+    void iqReceived(const QXmppIq &);
 
     /// This signal is emitted when SSL errors are encountered.
     void sslErrors(const QList<QSslError> &errors);
@@ -84,19 +83,19 @@ signals:
 protected:
     /// \cond
     // Overridable methods
-    virtual void handleStart();
-    virtual void handleStanza(const QDomElement &element);
-    virtual void handleStream(const QDomElement &element);
+    void handleStart() override;
+    void handleStanza(const QDomElement &element) override;
+    void handleStream(const QDomElement &element) override;
     /// \endcond
 
-public slots:
-    virtual void disconnectFromHost();
+public Q_SLOTS:
+    void disconnectFromHost() override;
 
-private slots:
+private Q_SLOTS:
     void _q_dnsLookupFinished();
     void _q_socketDisconnected();
     void socketError(QAbstractSocket::SocketError);
-    void socketSslErrors(const QList<QSslError>&);
+    void socketSslErrors(const QList<QSslError> &);
 
     void pingStart();
     void pingStop();
@@ -105,7 +104,7 @@ private slots:
 
 private:
     friend class QXmppOutgoingClientPrivate;
-    QXmppOutgoingClientPrivate * const d;
+    QXmppOutgoingClientPrivate *const d;
 };
 
-#endif // QXMPPOUTGOINGCLIENT_H
+#endif  // QXMPPOUTGOINGCLIENT_H
