@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Authors:
  *  Manjeet Dahiya
@@ -22,14 +22,15 @@
  *
  */
 
-#include <QDomElement>
+#include "QXmppRosterManager.h"
 
 #include "QXmppClient.h"
 #include "QXmppPresence.h"
 #include "QXmppRosterIq.h"
-#include "QXmppRosterManager.h"
 #include "QXmppUtils.h"
 
+#include <QDomElement>
+
 class QXmppRosterManagerPrivate
 {
 public:
@@ -39,7 +40,7 @@ public:
     QMap<QString, QXmppRosterIq::Item> entries;
 
     // map of resources of the jid and map of resources and presences
-    QMap<QString, QMap<QString, QXmppPresence> > presences;
+    QMap<QString, QMap<QString, QXmppPresence>> presences;
 
     // flag to store that the roster has been populated
     bool isRosterReceived;
@@ -53,30 +54,25 @@ private:
 
 QXmppRosterManagerPrivate::QXmppRosterManagerPrivate(QXmppRosterManager *qq)
     : isRosterReceived(false),
-    q(qq)
+      q(qq)
 {
 }
 
 /// Constructs a roster manager.
 
-QXmppRosterManager::QXmppRosterManager(QXmppClient* client)
+QXmppRosterManager::QXmppRosterManager(QXmppClient *client)
 {
-    bool check;
-    Q_UNUSED(check);
 
     d = new QXmppRosterManagerPrivate(this);
 
-    check = connect(client, SIGNAL(connected()),
-                    this, SLOT(_q_connected()));
-    Q_ASSERT(check);
+    connect(client, &QXmppClient::connected,
+            this, &QXmppRosterManager::_q_connected);
 
-    check = connect(client, SIGNAL(disconnected()),
-                    this, SLOT(_q_disconnected()));
-    Q_ASSERT(check);
+    connect(client, &QXmppClient::disconnected,
+            this, &QXmppRosterManager::_q_disconnected);
 
-    check = connect(client, SIGNAL(presenceReceived(QXmppPresence)),
-                    this, SLOT(_q_presenceReceived(QXmppPresence)));
-    Q_ASSERT(check);
+    connect(client, &QXmppClient::presenceReceived,
+            this, &QXmppRosterManager::_q_presenceReceived);
 }
 
 QXmppRosterManager::~QXmppRosterManager()
@@ -84,10 +80,19 @@ QXmppRosterManager::~QXmppRosterManager()
     delete d;
 }
 
-/// Accepts a subscription request.
 ///
-/// You can call this method in reply to the subscriptionRequest() signal.
-
+/// Accepts an existing subscription request or pre-approves future subscription
+/// requests.
+///
+/// You can call this method in reply to the subscriptionRequest() signal or to
+/// create a pre-approved subscription.
+///
+/// \note Pre-approving subscription requests is only allowed, if the server
+/// supports RFC6121 and advertises the 'urn:xmpp:features:pre-approval' stream
+/// feature.
+///
+/// \sa QXmppStreamFeatures::preApprovedSubscriptionsSupported()
+///
 bool QXmppRosterManager::acceptSubscription(const QString &bareJid, const QString &reason)
 {
     QXmppPresence presence;
@@ -132,52 +137,47 @@ bool QXmppRosterManager::handleStanza(const QDomElement &element)
     rosterIq.parse(element);
 
     bool isInitial = (d->rosterReqId == rosterIq.id());
-    switch(rosterIq.type())
-    {
-    case QXmppIq::Set:
-        {
-            // send result iq
-            QXmppIq returnIq(QXmppIq::Result);
-            returnIq.setId(rosterIq.id());
-            client()->sendPacket(returnIq);
+    switch (rosterIq.type()) {
+    case QXmppIq::Set: {
+        // send result iq
+        QXmppIq returnIq(QXmppIq::Result);
+        returnIq.setId(rosterIq.id());
+        client()->sendPacket(returnIq);
 
-            // store updated entries and notify changes
-            const QList<QXmppRosterIq::Item> items = rosterIq.items();
-            foreach (const QXmppRosterIq::Item &item, items) {
-                const QString bareJid = item.bareJid();
-                if (item.subscriptionType() == QXmppRosterIq::Item::Remove) {
-                    if (d->entries.remove(bareJid)) {
-                        // notify the user that the item was removed
-                        emit itemRemoved(bareJid);
-                    }
+        // store updated entries and notify changes
+        const QList<QXmppRosterIq::Item> items = rosterIq.items();
+        for (const auto &item : items) {
+            const QString bareJid = item.bareJid();
+            if (item.subscriptionType() == QXmppRosterIq::Item::Remove) {
+                if (d->entries.remove(bareJid)) {
+                    // notify the user that the item was removed
+                    emit itemRemoved(bareJid);
+                }
+            } else {
+                const bool added = !d->entries.contains(bareJid);
+                d->entries.insert(bareJid, item);
+                if (added) {
+                    // notify the user that the item was added
+                    emit itemAdded(bareJid);
                 } else {
-                    const bool added = !d->entries.contains(bareJid);
-                    d->entries.insert(bareJid, item);
-                    if (added) {
-                        // notify the user that the item was added
-                        emit itemAdded(bareJid);
-                    } else {
-                        // notify the user that the item changed
-                        emit itemChanged(bareJid);
-                    }
+                    // notify the user that the item changed
+                    emit itemChanged(bareJid);
                 }
             }
         }
-        break;
-    case QXmppIq::Result:
-        {
-            const QList<QXmppRosterIq::Item> items = rosterIq.items();
-            foreach (const QXmppRosterIq::Item &item, items) {
-                const QString bareJid = item.bareJid();
-                d->entries.insert(bareJid, item);
-            }
-            if (isInitial)
-            {
-                d->isRosterReceived = true;
-                emit rosterReceived();
-            }
-            break;
+    } break;
+    case QXmppIq::Result: {
+        const QList<QXmppRosterIq::Item> items = rosterIq.items();
+        for (const auto &item : items) {
+            const QString bareJid = item.bareJid();
+            d->entries.insert(bareJid, item);
         }
+        if (isInitial) {
+            d->isRosterReceived = true;
+            emit rosterReceived();
+        }
+        break;
+    }
     default:
         break;
     }
@@ -186,7 +186,7 @@ bool QXmppRosterManager::handleStanza(const QDomElement &element)
 }
 /// \endcond
 
-void QXmppRosterManager::_q_presenceReceived(const QXmppPresence& presence)
+void QXmppRosterManager::_q_presenceReceived(const QXmppPresence &presence)
 {
     const QString jid = presence.from();
     const QString bareJid = QXmppUtils::jidToBareJid(jid);
@@ -195,8 +195,7 @@ void QXmppRosterManager::_q_presenceReceived(const QXmppPresence& presence)
     if (bareJid.isEmpty())
         return;
 
-    switch(presence.type())
-    {
+    switch (presence.type()) {
     case QXmppPresence::Available:
         d->presences[bareJid][resource] = presence;
         emit presenceChanged(bareJid, resource);
@@ -206,8 +205,7 @@ void QXmppRosterManager::_q_presenceReceived(const QXmppPresence& presence)
         emit presenceChanged(bareJid, resource);
         break;
     case QXmppPresence::Subscribe:
-        if (client()->configuration().autoAcceptSubscriptions())
-        {
+        if (client()->configuration().autoAcceptSubscriptions()) {
             // accept subscription request
             acceptSubscription(bareJid);
 
@@ -293,6 +291,10 @@ bool QXmppRosterManager::renameItem(const QString &bareJid, const QString &name)
     QXmppRosterIq::Item item = d->entries.value(bareJid);
     item.setName(name);
 
+    // If there is a pending subscription, do not include the corresponding attribute in the stanza.
+    if (!item.subscriptionStatus().isEmpty())
+        item.setSubscriptionStatus({});
+
     QXmppRosterIq iq;
     iq.setType(QXmppIq::Set);
     iq.addItem(item);
@@ -344,10 +346,10 @@ QStringList QXmppRosterManager::getRosterBareJids() const
 ///
 
 QXmppRosterIq::Item QXmppRosterManager::getRosterEntry(
-        const QString& bareJid) const
+    const QString &bareJid) const
 {
     // will return blank entry if bareJid doesn't exist
-    if(d->entries.contains(bareJid))
+    if (d->entries.contains(bareJid))
         return d->entries.value(bareJid);
     else
         return QXmppRosterIq::Item();
@@ -359,9 +361,9 @@ QXmppRosterIq::Item QXmppRosterManager::getRosterEntry(
 /// \return list of associated resources as a QStringList
 ///
 
-QStringList QXmppRosterManager::getResources(const QString& bareJid) const
+QStringList QXmppRosterManager::getResources(const QString &bareJid) const
 {
-    if(d->presences.contains(bareJid))
+    if (d->presences.contains(bareJid))
         return d->presences[bareJid].keys();
     else
         return QStringList();
@@ -376,9 +378,9 @@ QStringList QXmppRosterManager::getResources(const QString& bareJid) const
 ///
 
 QMap<QString, QXmppPresence> QXmppRosterManager::getAllPresencesForBareJid(
-        const QString& bareJid) const
+    const QString &bareJid) const
 {
-    if(d->presences.contains(bareJid))
+    if (d->presences.contains(bareJid))
         return d->presences[bareJid];
     else
         return QMap<QString, QXmppPresence>();
@@ -391,13 +393,12 @@ QMap<QString, QXmppPresence> QXmppRosterManager::getAllPresencesForBareJid(
 /// \return QXmppPresence
 ///
 
-QXmppPresence QXmppRosterManager::getPresence(const QString& bareJid,
-                                       const QString& resource) const
+QXmppPresence QXmppRosterManager::getPresence(const QString &bareJid,
+                                              const QString &resource) const
 {
-    if(d->presences.contains(bareJid) && d->presences[bareJid].contains(resource))
+    if (d->presences.contains(bareJid) && d->presences[bareJid].contains(resource))
         return d->presences[bareJid][resource];
-    else
-    {
+    else {
         QXmppPresence presence;
         presence.setType(QXmppPresence::Unavailable);
         return presence;
