@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -29,40 +29,45 @@
 class QXmppVersionIq;
 class QXmppVersionManagerPrivate;
 
+///
 /// \brief The QXmppVersionManager class makes it possible to request for
-/// the software version of an entity as defined by XEP-0092: Software Version.
+/// the software version of an entity as defined by \xep{0092}: Software Version.
+///
+/// \note It's object should not be created using it's constructor. Instead
+/// \c QXmppClient::findExtension<QXmppVersionManager>() should be used to get
+/// the instantiated object of this class.
 ///
 /// \ingroup Managers
-
+///
 class QXMPP_EXPORT QXmppVersionManager : public QXmppClientExtension
 {
     Q_OBJECT
 
 public:
     QXmppVersionManager();
-    ~QXmppVersionManager();
+    ~QXmppVersionManager() override;
 
-    QString requestVersion(const QString& jid);
+    QString requestVersion(const QString &jid);
 
-    void setClientName(const QString&);
-    void setClientVersion(const QString&);
-    void setClientOs(const QString&);
+    void setClientName(const QString &);
+    void setClientVersion(const QString &);
+    void setClientOs(const QString &);
 
     QString clientName() const;
     QString clientVersion() const;
     QString clientOs() const;
 
     /// \cond
-    QStringList discoveryFeatures() const;
-    bool handleStanza(const QDomElement &element);
+    QStringList discoveryFeatures() const override;
+    bool handleStanza(const QDomElement &element) override;
     /// \endcond
 
-signals:
+Q_SIGNALS:
     /// \brief This signal is emitted when a version response is received.
-    void versionReceived(const QXmppVersionIq&);
+    void versionReceived(const QXmppVersionIq &);
 
 private:
     QXmppVersionManagerPrivate *d;
 };
 
-#endif // QXMPPVERSIONMANAGER_H
+#endif  // QXMPPVERSIONMANAGER_H
