@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2019 The QXmpp developers
+ * Copyright (C) 2008-2020 The QXmpp developers
  *
  * Authors:
  *  Jeremy Lainé
@@ -21,15 +21,13 @@
  *
  */
 
-#include <QBuffer>
-#include <QObject>
-
 #include "QXmppCallManager.h"
 #include "QXmppClient.h"
 #include "QXmppServer.h"
-#include "util.h"
 
-//Q_DECLARE_METATYPE(QXmppTransferJob::Method)
+#include "util.h"
+#include <QBuffer>
+#include <QObject>
 
 class tst_QXmppCallManager : public QObject
 {
@@ -47,7 +45,7 @@ private:
 
 void tst_QXmppCallManager::init()
 {
-    receiverCall = 0;
+    receiverCall = nullptr;
 }
 
 void tst_QXmppCallManager::acceptCall(QXmppCall *call)
@@ -77,13 +75,13 @@ void tst_QXmppCallManager::testCall()
 
     // prepare sender
     QXmppClient sender;
-    QXmppCallManager *senderManager = new QXmppCallManager;
+    auto *senderManager = new QXmppCallManager;
     sender.addExtension(senderManager);
     sender.setLogger(&logger);
 
     QEventLoop senderLoop;
-    connect(&sender, SIGNAL(connected()), &senderLoop, SLOT(quit()));
-    connect(&sender, SIGNAL(disconnected()), &senderLoop, SLOT(quit()));
+    connect(&sender, &QXmppClient::connected, &senderLoop, &QEventLoop::quit);
+    connect(&sender, &QXmppClient::disconnected, &senderLoop, &QEventLoop::quit);
 
     QXmppConfiguration config;
     config.setDomain(testDomain);
@@ -97,15 +95,15 @@ void tst_QXmppCallManager::testCall()
 
     // prepare receiver
     QXmppClient receiver;
-    QXmppCallManager *receiverManager = new QXmppCallManager;
-    connect(receiverManager, SIGNAL(callReceived(QXmppCall*)),
-            this, SLOT(acceptCall(QXmppCall*)));
+    auto *receiverManager = new QXmppCallManager;
+    connect(receiverManager, &QXmppCallManager::callReceived,
+            this, &tst_QXmppCallManager::acceptCall);
     receiver.addExtension(receiverManager);
     receiver.setLogger(&logger);
 
     QEventLoop receiverLoop;
-    connect(&receiver, SIGNAL(connected()), &receiverLoop, SLOT(quit()));
-    connect(&receiver, SIGNAL(disconnected()), &receiverLoop, SLOT(quit()));
+    connect(&receiver, &QXmppClient::connected, &receiverLoop, &QEventLoop::quit);
+    connect(&receiver, &QXmppClient::disconnected, &receiverLoop, &QEventLoop::quit);
 
     config.setUser("receiver");
     config.setPassword("testpwd");
@@ -118,7 +116,7 @@ void tst_QXmppCallManager::testCall()
     QEventLoop loop;
     QXmppCall *senderCall = senderManager->call("receiver@localhost/QXmpp");
     QVERIFY(senderCall);
-    connect(senderCall, SIGNAL(connected()), &loop, SLOT(quit()));
+    connect(senderCall, &QXmppCall::connected, &loop, &QEventLoop::quit);
     loop.exec();
     QVERIFY(receiverCall);
 
@@ -130,12 +128,12 @@ void tst_QXmppCallManager::testCall()
 
     // exchange some media
     qDebug() << "======== TALK ========";
-    QTimer::singleShot(2000, &loop, SLOT(quit()));
+    QTimer::singleShot(2000, &loop, &QEventLoop::quit);
     loop.exec();
 
     // hangup call
     qDebug() << "======== HANGUP ========";
-    connect(senderCall, SIGNAL(finished()), &loop, SLOT(quit()));
+    connect(senderCall, &QXmppCall::finished, &loop, &QEventLoop::quit);
     senderCall->hangup();
     loop.exec();
 
